/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_mdba_mdb_eattr_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_mdba_mdb_eattr_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_mdba_mdb_eattr_attrs_xdata[] = {
 [MDBA_MDB_EATTR_UNSPEC] = XLAT(MDBA_MDB_EATTR_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (MDBA_MDB_EATTR_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(MDBA_MDB_EATTR_UNSPEC)
 [MDBA_MDB_EATTR_TIMER] = XLAT(MDBA_MDB_EATTR_TIMER),
 #define XLAT_VAL_1 ((unsigned) (MDBA_MDB_EATTR_TIMER))
 #define XLAT_STR_1 STRINGIFY(MDBA_MDB_EATTR_TIMER)
 [MDBA_MDB_EATTR_SRC_LIST] = XLAT(MDBA_MDB_EATTR_SRC_LIST),
 #define XLAT_VAL_2 ((unsigned) (MDBA_MDB_EATTR_SRC_LIST))
 #define XLAT_STR_2 STRINGIFY(MDBA_MDB_EATTR_SRC_LIST)
 [MDBA_MDB_EATTR_GROUP_MODE] = XLAT(MDBA_MDB_EATTR_GROUP_MODE),
 #define XLAT_VAL_3 ((unsigned) (MDBA_MDB_EATTR_GROUP_MODE))
 #define XLAT_STR_3 STRINGIFY(MDBA_MDB_EATTR_GROUP_MODE)
 [MDBA_MDB_EATTR_SOURCE] = XLAT(MDBA_MDB_EATTR_SOURCE),
 #define XLAT_VAL_4 ((unsigned) (MDBA_MDB_EATTR_SOURCE))
 #define XLAT_STR_4 STRINGIFY(MDBA_MDB_EATTR_SOURCE)
 [MDBA_MDB_EATTR_RTPROT] = XLAT(MDBA_MDB_EATTR_RTPROT),
 #define XLAT_VAL_5 ((unsigned) (MDBA_MDB_EATTR_RTPROT))
 #define XLAT_STR_5 STRINGIFY(MDBA_MDB_EATTR_RTPROT)
};
static
const struct xlat rtnl_mdba_mdb_eattr_attrs[1] = { {
 .data = rtnl_mdba_mdb_eattr_attrs_xdata,
 .size = ARRAY_SIZE(rtnl_mdba_mdb_eattr_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
