/* Generated by ./src/xlat/gen.sh from ./src/xlat/advise.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(POSIX_FADV_NORMAL) || (defined(HAVE_DECL_POSIX_FADV_NORMAL) && HAVE_DECL_POSIX_FADV_NORMAL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((POSIX_FADV_NORMAL) == (0), "POSIX_FADV_NORMAL != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define POSIX_FADV_NORMAL 0
#endif
#if defined(POSIX_FADV_RANDOM) || (defined(HAVE_DECL_POSIX_FADV_RANDOM) && HAVE_DECL_POSIX_FADV_RANDOM)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((POSIX_FADV_RANDOM) == (1), "POSIX_FADV_RANDOM != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define POSIX_FADV_RANDOM 1
#endif
#if defined(POSIX_FADV_SEQUENTIAL) || (defined(HAVE_DECL_POSIX_FADV_SEQUENTIAL) && HAVE_DECL_POSIX_FADV_SEQUENTIAL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((POSIX_FADV_SEQUENTIAL) == (2), "POSIX_FADV_SEQUENTIAL != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define POSIX_FADV_SEQUENTIAL 2
#endif
#if defined(POSIX_FADV_WILLNEED) || (defined(HAVE_DECL_POSIX_FADV_WILLNEED) && HAVE_DECL_POSIX_FADV_WILLNEED)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((POSIX_FADV_WILLNEED) == (3), "POSIX_FADV_WILLNEED != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define POSIX_FADV_WILLNEED 3
#endif
#if defined __s390x__
#if defined(POSIX_FADV_DONTNEED) || (defined(HAVE_DECL_POSIX_FADV_DONTNEED) && HAVE_DECL_POSIX_FADV_DONTNEED)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((POSIX_FADV_DONTNEED) == (6), "POSIX_FADV_DONTNEED != 6");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define POSIX_FADV_DONTNEED 6
#endif
#if defined(POSIX_FADV_NOREUSE) || (defined(HAVE_DECL_POSIX_FADV_NOREUSE) && HAVE_DECL_POSIX_FADV_NOREUSE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((POSIX_FADV_NOREUSE) == (7), "POSIX_FADV_NOREUSE != 7");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define POSIX_FADV_NOREUSE 7
#endif
#else
#if defined(POSIX_FADV_DONTNEED) || (defined(HAVE_DECL_POSIX_FADV_DONTNEED) && HAVE_DECL_POSIX_FADV_DONTNEED)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((POSIX_FADV_DONTNEED) == (4), "POSIX_FADV_DONTNEED != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define POSIX_FADV_DONTNEED 4
#endif
#if defined(POSIX_FADV_NOREUSE) || (defined(HAVE_DECL_POSIX_FADV_NOREUSE) && HAVE_DECL_POSIX_FADV_NOREUSE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((POSIX_FADV_NOREUSE) == (5), "POSIX_FADV_NOREUSE != 5");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define POSIX_FADV_NOREUSE 5
#endif
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat advise in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data advise_xdata[] = {
 XLAT(POSIX_FADV_NORMAL),
 #define XLAT_VAL_0 ((unsigned) (POSIX_FADV_NORMAL))
 #define XLAT_STR_0 STRINGIFY(POSIX_FADV_NORMAL)
 XLAT(POSIX_FADV_RANDOM),
 #define XLAT_VAL_1 ((unsigned) (POSIX_FADV_RANDOM))
 #define XLAT_STR_1 STRINGIFY(POSIX_FADV_RANDOM)
 XLAT(POSIX_FADV_SEQUENTIAL),
 #define XLAT_VAL_2 ((unsigned) (POSIX_FADV_SEQUENTIAL))
 #define XLAT_STR_2 STRINGIFY(POSIX_FADV_SEQUENTIAL)
 XLAT(POSIX_FADV_WILLNEED),
 #define XLAT_VAL_3 ((unsigned) (POSIX_FADV_WILLNEED))
 #define XLAT_STR_3 STRINGIFY(POSIX_FADV_WILLNEED)
#if defined __s390x__
 XLAT(POSIX_FADV_DONTNEED),
 #define XLAT_VAL_4 ((unsigned) (POSIX_FADV_DONTNEED))
 #define XLAT_STR_4 STRINGIFY(POSIX_FADV_DONTNEED)
 XLAT(POSIX_FADV_NOREUSE),
 #define XLAT_VAL_5 ((unsigned) (POSIX_FADV_NOREUSE))
 #define XLAT_STR_5 STRINGIFY(POSIX_FADV_NOREUSE)
#else
 XLAT(POSIX_FADV_DONTNEED),
 #define XLAT_VAL_6 ((unsigned) (POSIX_FADV_DONTNEED))
 #define XLAT_STR_6 STRINGIFY(POSIX_FADV_DONTNEED)
 XLAT(POSIX_FADV_NOREUSE),
 #define XLAT_VAL_7 ((unsigned) (POSIX_FADV_NOREUSE))
 #define XLAT_STR_7 STRINGIFY(POSIX_FADV_NOREUSE)
#endif
};
static
const struct xlat advise[1] = { {
 .data = advise_xdata,
 .size = ARRAY_SIZE(advise_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
