/* Generated by ./src/xlat/gen.sh from ./src/xlat/mlockall_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined __alpha__ || defined __powerpc__ || defined __powerpc64__ || defined __sparc__
#if defined(MCL_CURRENT) || (defined(HAVE_DECL_MCL_CURRENT) && HAVE_DECL_MCL_CURRENT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MCL_CURRENT) == (0x2000), "MCL_CURRENT != 0x2000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MCL_CURRENT 0x2000
#endif
#if defined(MCL_FUTURE) || (defined(HAVE_DECL_MCL_FUTURE) && HAVE_DECL_MCL_FUTURE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MCL_FUTURE) == (0x4000), "MCL_FUTURE != 0x4000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MCL_FUTURE 0x4000
#endif
#if defined(MCL_ONFAULT) || (defined(HAVE_DECL_MCL_ONFAULT) && HAVE_DECL_MCL_ONFAULT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MCL_ONFAULT) == (0x8000), "MCL_ONFAULT != 0x8000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MCL_ONFAULT 0x8000
#endif
#else
#if defined(MCL_CURRENT) || (defined(HAVE_DECL_MCL_CURRENT) && HAVE_DECL_MCL_CURRENT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MCL_CURRENT) == (1), "MCL_CURRENT != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MCL_CURRENT 1
#endif
#if defined(MCL_FUTURE) || (defined(HAVE_DECL_MCL_FUTURE) && HAVE_DECL_MCL_FUTURE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MCL_FUTURE) == (2), "MCL_FUTURE != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MCL_FUTURE 2
#endif
#if defined(MCL_ONFAULT) || (defined(HAVE_DECL_MCL_ONFAULT) && HAVE_DECL_MCL_ONFAULT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MCL_ONFAULT) == (4), "MCL_ONFAULT != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MCL_ONFAULT 4
#endif
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat mlockall_flags in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data mlockall_flags_xdata[] = {
#if defined __alpha__ || defined __powerpc__ || defined __powerpc64__ || defined __sparc__
 XLAT(MCL_CURRENT),
 #define XLAT_VAL_0 ((unsigned) (MCL_CURRENT))
 #define XLAT_STR_0 STRINGIFY(MCL_CURRENT)
 XLAT(MCL_FUTURE),
 #define XLAT_VAL_1 ((unsigned) (MCL_FUTURE))
 #define XLAT_STR_1 STRINGIFY(MCL_FUTURE)
 XLAT(MCL_ONFAULT),
 #define XLAT_VAL_2 ((unsigned) (MCL_ONFAULT))
 #define XLAT_STR_2 STRINGIFY(MCL_ONFAULT)
#else
 XLAT(MCL_CURRENT),
 #define XLAT_VAL_3 ((unsigned) (MCL_CURRENT))
 #define XLAT_STR_3 STRINGIFY(MCL_CURRENT)
 XLAT(MCL_FUTURE),
 #define XLAT_VAL_4 ((unsigned) (MCL_FUTURE))
 #define XLAT_STR_4 STRINGIFY(MCL_FUTURE)
 XLAT(MCL_ONFAULT),
 #define XLAT_VAL_5 ((unsigned) (MCL_ONFAULT))
 #define XLAT_STR_5 STRINGIFY(MCL_ONFAULT)
#endif
};
static
const struct xlat mlockall_flags[1] = { {
 .data = mlockall_flags_xdata,
 .size = ARRAY_SIZE(mlockall_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
