/* Generated by ./src/xlat/gen.sh from ./src/xlat/getsock_ipv6_options.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat getsock_ipv6_options in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data getsock_ipv6_options_xdata[] = {
/*
* Options specific to getsockopt(SOL_IPV6).
* Common {g,s}etsockopt(SOL_IPV6) options
* should be in sock_ipv6_options.in instead.
*/

#if defined(IP6T_SO_GET_INFO) || (defined(HAVE_DECL_IP6T_SO_GET_INFO) && HAVE_DECL_IP6T_SO_GET_INFO)
  XLAT(IP6T_SO_GET_INFO),
 #define XLAT_VAL_0 ((unsigned) (IP6T_SO_GET_INFO))
 #define XLAT_STR_0 STRINGIFY(IP6T_SO_GET_INFO)
#endif
#if defined(IP6T_SO_GET_ENTRIES) || (defined(HAVE_DECL_IP6T_SO_GET_ENTRIES) && HAVE_DECL_IP6T_SO_GET_ENTRIES)
  XLAT(IP6T_SO_GET_ENTRIES),
 #define XLAT_VAL_1 ((unsigned) (IP6T_SO_GET_ENTRIES))
 #define XLAT_STR_1 STRINGIFY(IP6T_SO_GET_ENTRIES)
#endif
#if defined(IP6T_SO_GET_REVISION_MATCH) || (defined(HAVE_DECL_IP6T_SO_GET_REVISION_MATCH) && HAVE_DECL_IP6T_SO_GET_REVISION_MATCH)
  XLAT(IP6T_SO_GET_REVISION_MATCH),
 #define XLAT_VAL_2 ((unsigned) (IP6T_SO_GET_REVISION_MATCH))
 #define XLAT_STR_2 STRINGIFY(IP6T_SO_GET_REVISION_MATCH)
#endif
#if defined(IP6T_SO_GET_REVISION_TARGET) || (defined(HAVE_DECL_IP6T_SO_GET_REVISION_TARGET) && HAVE_DECL_IP6T_SO_GET_REVISION_TARGET)
  XLAT(IP6T_SO_GET_REVISION_TARGET),
 #define XLAT_VAL_3 ((unsigned) (IP6T_SO_GET_REVISION_TARGET))
 #define XLAT_STR_3 STRINGIFY(IP6T_SO_GET_REVISION_TARGET)
#endif
};
static
const struct xlat getsock_ipv6_options[1] = { {
 .data = getsock_ipv6_options_xdata,
 .size = ARRAY_SIZE(getsock_ipv6_options_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
