/* Generated by ./src/xlat/gen.sh from ./src/xlat/btrfs_balance_args.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

extern const struct xlat btrfs_balance_args[];

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data btrfs_balance_args_xdata[] = {
 XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_PROFILES),
 #define XLAT_VAL_0 ((uint64_t) (BTRFS_BALANCE_ARGS_PROFILES))
 #define XLAT_STR_0 STRINGIFY(BTRFS_BALANCE_ARGS_PROFILES)
 XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_USAGE),
 #define XLAT_VAL_1 ((uint64_t) (BTRFS_BALANCE_ARGS_USAGE))
 #define XLAT_STR_1 STRINGIFY(BTRFS_BALANCE_ARGS_USAGE)
 XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_DEVID),
 #define XLAT_VAL_2 ((uint64_t) (BTRFS_BALANCE_ARGS_DEVID))
 #define XLAT_STR_2 STRINGIFY(BTRFS_BALANCE_ARGS_DEVID)
 XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_DRANGE),
 #define XLAT_VAL_3 ((uint64_t) (BTRFS_BALANCE_ARGS_DRANGE))
 #define XLAT_STR_3 STRINGIFY(BTRFS_BALANCE_ARGS_DRANGE)
 XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_VRANGE),
 #define XLAT_VAL_4 ((uint64_t) (BTRFS_BALANCE_ARGS_VRANGE))
 #define XLAT_STR_4 STRINGIFY(BTRFS_BALANCE_ARGS_VRANGE)
 XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_LIMIT),
 #define XLAT_VAL_5 ((uint64_t) (BTRFS_BALANCE_ARGS_LIMIT))
 #define XLAT_STR_5 STRINGIFY(BTRFS_BALANCE_ARGS_LIMIT)
 XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_LIMIT_RANGE),
 #define XLAT_VAL_6 ((uint64_t) (BTRFS_BALANCE_ARGS_LIMIT_RANGE))
 #define XLAT_STR_6 STRINGIFY(BTRFS_BALANCE_ARGS_LIMIT_RANGE)
 XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_STRIPES_RANGE),
 #define XLAT_VAL_7 ((uint64_t) (BTRFS_BALANCE_ARGS_STRIPES_RANGE))
 #define XLAT_STR_7 STRINGIFY(BTRFS_BALANCE_ARGS_STRIPES_RANGE)
 XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_CONVERT),
 #define XLAT_VAL_8 ((uint64_t) (BTRFS_BALANCE_ARGS_CONVERT))
 #define XLAT_STR_8 STRINGIFY(BTRFS_BALANCE_ARGS_CONVERT)
 XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_SOFT),
 #define XLAT_VAL_9 ((uint64_t) (BTRFS_BALANCE_ARGS_SOFT))
 #define XLAT_STR_9 STRINGIFY(BTRFS_BALANCE_ARGS_SOFT)
 XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_USAGE_RANGE),
 #define XLAT_VAL_10 ((uint64_t) (BTRFS_BALANCE_ARGS_USAGE_RANGE))
 #define XLAT_STR_10 STRINGIFY(BTRFS_BALANCE_ARGS_USAGE_RANGE)
};
#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
static
#  endif
const struct xlat btrfs_balance_args[1] = { {
 .data = btrfs_balance_args_xdata,
 .size = ARRAY_SIZE(btrfs_balance_args_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
