/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_ifla_br_boolopts.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BR_BOOLOPT_NO_LL_LEARN) == (0), "BR_BOOLOPT_NO_LL_LEARN != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BR_BOOLOPT_MCAST_VLAN_SNOOPING) == (1), "BR_BOOLOPT_MCAST_VLAN_SNOOPING != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BR_BOOLOPT_MST_ENABLE) == (2), "BR_BOOLOPT_MST_ENABLE != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_ifla_br_boolopts in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_ifla_br_boolopts_xdata[] = {
 [BR_BOOLOPT_NO_LL_LEARN] = XLAT(BR_BOOLOPT_NO_LL_LEARN),
 #define XLAT_VAL_0 ((unsigned) (BR_BOOLOPT_NO_LL_LEARN))
 #define XLAT_STR_0 STRINGIFY(BR_BOOLOPT_NO_LL_LEARN)
 [BR_BOOLOPT_MCAST_VLAN_SNOOPING] = XLAT(BR_BOOLOPT_MCAST_VLAN_SNOOPING),
 #define XLAT_VAL_1 ((unsigned) (BR_BOOLOPT_MCAST_VLAN_SNOOPING))
 #define XLAT_STR_1 STRINGIFY(BR_BOOLOPT_MCAST_VLAN_SNOOPING)
 [BR_BOOLOPT_MST_ENABLE] = XLAT(BR_BOOLOPT_MST_ENABLE),
 #define XLAT_VAL_2 ((unsigned) (BR_BOOLOPT_MST_ENABLE))
 #define XLAT_STR_2 STRINGIFY(BR_BOOLOPT_MST_ENABLE)
};
static
const struct xlat rtnl_ifla_br_boolopts[1] = { {
 .data = rtnl_ifla_br_boolopts_xdata,
 .size = ARRAY_SIZE(rtnl_ifla_br_boolopts_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
