/* Generated by ./src/xlat/gen.sh from ./src/xlat/evdev_abs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifndef IN_MPERS

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data evdev_abs_xdata[] = {
 [ABS_X] = XLAT(ABS_X),
 #define XLAT_VAL_0 ((unsigned) (ABS_X))
 #define XLAT_STR_0 STRINGIFY(ABS_X)
 [ABS_Y] = XLAT(ABS_Y),
 #define XLAT_VAL_1 ((unsigned) (ABS_Y))
 #define XLAT_STR_1 STRINGIFY(ABS_Y)
 [ABS_Z] = XLAT(ABS_Z),
 #define XLAT_VAL_2 ((unsigned) (ABS_Z))
 #define XLAT_STR_2 STRINGIFY(ABS_Z)
 [ABS_RX] = XLAT(ABS_RX),
 #define XLAT_VAL_3 ((unsigned) (ABS_RX))
 #define XLAT_STR_3 STRINGIFY(ABS_RX)
 [ABS_RY] = XLAT(ABS_RY),
 #define XLAT_VAL_4 ((unsigned) (ABS_RY))
 #define XLAT_STR_4 STRINGIFY(ABS_RY)
 [ABS_RZ] = XLAT(ABS_RZ),
 #define XLAT_VAL_5 ((unsigned) (ABS_RZ))
 #define XLAT_STR_5 STRINGIFY(ABS_RZ)
 [ABS_THROTTLE] = XLAT(ABS_THROTTLE),
 #define XLAT_VAL_6 ((unsigned) (ABS_THROTTLE))
 #define XLAT_STR_6 STRINGIFY(ABS_THROTTLE)
 [ABS_RUDDER] = XLAT(ABS_RUDDER),
 #define XLAT_VAL_7 ((unsigned) (ABS_RUDDER))
 #define XLAT_STR_7 STRINGIFY(ABS_RUDDER)
 [ABS_WHEEL] = XLAT(ABS_WHEEL),
 #define XLAT_VAL_8 ((unsigned) (ABS_WHEEL))
 #define XLAT_STR_8 STRINGIFY(ABS_WHEEL)
 [ABS_GAS] = XLAT(ABS_GAS),
 #define XLAT_VAL_9 ((unsigned) (ABS_GAS))
 #define XLAT_STR_9 STRINGIFY(ABS_GAS)
 [ABS_BRAKE] = XLAT(ABS_BRAKE),
 #define XLAT_VAL_10 ((unsigned) (ABS_BRAKE))
 #define XLAT_STR_10 STRINGIFY(ABS_BRAKE)
 [ABS_HAT0X] = XLAT(ABS_HAT0X),
 #define XLAT_VAL_11 ((unsigned) (ABS_HAT0X))
 #define XLAT_STR_11 STRINGIFY(ABS_HAT0X)
 [ABS_HAT0Y] = XLAT(ABS_HAT0Y),
 #define XLAT_VAL_12 ((unsigned) (ABS_HAT0Y))
 #define XLAT_STR_12 STRINGIFY(ABS_HAT0Y)
 [ABS_HAT1X] = XLAT(ABS_HAT1X),
 #define XLAT_VAL_13 ((unsigned) (ABS_HAT1X))
 #define XLAT_STR_13 STRINGIFY(ABS_HAT1X)
 [ABS_HAT1Y] = XLAT(ABS_HAT1Y),
 #define XLAT_VAL_14 ((unsigned) (ABS_HAT1Y))
 #define XLAT_STR_14 STRINGIFY(ABS_HAT1Y)
 [ABS_HAT2X] = XLAT(ABS_HAT2X),
 #define XLAT_VAL_15 ((unsigned) (ABS_HAT2X))
 #define XLAT_STR_15 STRINGIFY(ABS_HAT2X)
 [ABS_HAT2Y] = XLAT(ABS_HAT2Y),
 #define XLAT_VAL_16 ((unsigned) (ABS_HAT2Y))
 #define XLAT_STR_16 STRINGIFY(ABS_HAT2Y)
 [ABS_HAT3X] = XLAT(ABS_HAT3X),
 #define XLAT_VAL_17 ((unsigned) (ABS_HAT3X))
 #define XLAT_STR_17 STRINGIFY(ABS_HAT3X)
 [ABS_HAT3Y] = XLAT(ABS_HAT3Y),
 #define XLAT_VAL_18 ((unsigned) (ABS_HAT3Y))
 #define XLAT_STR_18 STRINGIFY(ABS_HAT3Y)
 [ABS_PRESSURE] = XLAT(ABS_PRESSURE),
 #define XLAT_VAL_19 ((unsigned) (ABS_PRESSURE))
 #define XLAT_STR_19 STRINGIFY(ABS_PRESSURE)
 [ABS_DISTANCE] = XLAT(ABS_DISTANCE),
 #define XLAT_VAL_20 ((unsigned) (ABS_DISTANCE))
 #define XLAT_STR_20 STRINGIFY(ABS_DISTANCE)
 [ABS_TILT_X] = XLAT(ABS_TILT_X),
 #define XLAT_VAL_21 ((unsigned) (ABS_TILT_X))
 #define XLAT_STR_21 STRINGIFY(ABS_TILT_X)
 [ABS_TILT_Y] = XLAT(ABS_TILT_Y),
 #define XLAT_VAL_22 ((unsigned) (ABS_TILT_Y))
 #define XLAT_STR_22 STRINGIFY(ABS_TILT_Y)
 [ABS_TOOL_WIDTH] = XLAT(ABS_TOOL_WIDTH),
 #define XLAT_VAL_23 ((unsigned) (ABS_TOOL_WIDTH))
 #define XLAT_STR_23 STRINGIFY(ABS_TOOL_WIDTH)
 [ABS_VOLUME] = XLAT(ABS_VOLUME),
 #define XLAT_VAL_24 ((unsigned) (ABS_VOLUME))
 #define XLAT_STR_24 STRINGIFY(ABS_VOLUME)
 [ABS_MISC] = XLAT(ABS_MISC),
 #define XLAT_VAL_25 ((unsigned) (ABS_MISC))
 #define XLAT_STR_25 STRINGIFY(ABS_MISC)
 [ABS_RESERVED] = XLAT(ABS_RESERVED),
 #define XLAT_VAL_26 ((unsigned) (ABS_RESERVED))
 #define XLAT_STR_26 STRINGIFY(ABS_RESERVED)
 [ABS_MT_SLOT] = XLAT(ABS_MT_SLOT),
 #define XLAT_VAL_27 ((unsigned) (ABS_MT_SLOT))
 #define XLAT_STR_27 STRINGIFY(ABS_MT_SLOT)
 [ABS_MT_TOUCH_MAJOR] = XLAT(ABS_MT_TOUCH_MAJOR),
 #define XLAT_VAL_28 ((unsigned) (ABS_MT_TOUCH_MAJOR))
 #define XLAT_STR_28 STRINGIFY(ABS_MT_TOUCH_MAJOR)
 [ABS_MT_TOUCH_MINOR] = XLAT(ABS_MT_TOUCH_MINOR),
 #define XLAT_VAL_29 ((unsigned) (ABS_MT_TOUCH_MINOR))
 #define XLAT_STR_29 STRINGIFY(ABS_MT_TOUCH_MINOR)
 [ABS_MT_WIDTH_MAJOR] = XLAT(ABS_MT_WIDTH_MAJOR),
 #define XLAT_VAL_30 ((unsigned) (ABS_MT_WIDTH_MAJOR))
 #define XLAT_STR_30 STRINGIFY(ABS_MT_WIDTH_MAJOR)
 [ABS_MT_WIDTH_MINOR] = XLAT(ABS_MT_WIDTH_MINOR),
 #define XLAT_VAL_31 ((unsigned) (ABS_MT_WIDTH_MINOR))
 #define XLAT_STR_31 STRINGIFY(ABS_MT_WIDTH_MINOR)
 [ABS_MT_ORIENTATION] = XLAT(ABS_MT_ORIENTATION),
 #define XLAT_VAL_32 ((unsigned) (ABS_MT_ORIENTATION))
 #define XLAT_STR_32 STRINGIFY(ABS_MT_ORIENTATION)
 [ABS_MT_POSITION_X] = XLAT(ABS_MT_POSITION_X),
 #define XLAT_VAL_33 ((unsigned) (ABS_MT_POSITION_X))
 #define XLAT_STR_33 STRINGIFY(ABS_MT_POSITION_X)
 [ABS_MT_POSITION_Y] = XLAT(ABS_MT_POSITION_Y),
 #define XLAT_VAL_34 ((unsigned) (ABS_MT_POSITION_Y))
 #define XLAT_STR_34 STRINGIFY(ABS_MT_POSITION_Y)
 [ABS_MT_TOOL_TYPE] = XLAT(ABS_MT_TOOL_TYPE),
 #define XLAT_VAL_35 ((unsigned) (ABS_MT_TOOL_TYPE))
 #define XLAT_STR_35 STRINGIFY(ABS_MT_TOOL_TYPE)
 [ABS_MT_BLOB_ID] = XLAT(ABS_MT_BLOB_ID),
 #define XLAT_VAL_36 ((unsigned) (ABS_MT_BLOB_ID))
 #define XLAT_STR_36 STRINGIFY(ABS_MT_BLOB_ID)
 [ABS_MT_TRACKING_ID] = XLAT(ABS_MT_TRACKING_ID),
 #define XLAT_VAL_37 ((unsigned) (ABS_MT_TRACKING_ID))
 #define XLAT_STR_37 STRINGIFY(ABS_MT_TRACKING_ID)
 [ABS_MT_PRESSURE] = XLAT(ABS_MT_PRESSURE),
 #define XLAT_VAL_38 ((unsigned) (ABS_MT_PRESSURE))
 #define XLAT_STR_38 STRINGIFY(ABS_MT_PRESSURE)
 [ABS_MT_DISTANCE] = XLAT(ABS_MT_DISTANCE),
 #define XLAT_VAL_39 ((unsigned) (ABS_MT_DISTANCE))
 #define XLAT_STR_39 STRINGIFY(ABS_MT_DISTANCE)
 [ABS_MT_TOOL_X] = XLAT(ABS_MT_TOOL_X),
 #define XLAT_VAL_40 ((unsigned) (ABS_MT_TOOL_X))
 #define XLAT_STR_40 STRINGIFY(ABS_MT_TOOL_X)
 [ABS_MT_TOOL_Y] = XLAT(ABS_MT_TOOL_Y),
 #define XLAT_VAL_41 ((unsigned) (ABS_MT_TOOL_Y))
 #define XLAT_STR_41 STRINGIFY(ABS_MT_TOOL_Y)
};
const struct xlat evdev_abs[1] = { {
 .data = evdev_abs_xdata,
 .size = ARRAY_SIZE(evdev_abs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
#  ifdef XLAT_VAL_15
  | XLAT_VAL_15
#  endif
#  ifdef XLAT_VAL_16
  | XLAT_VAL_16
#  endif
#  ifdef XLAT_VAL_17
  | XLAT_VAL_17
#  endif
#  ifdef XLAT_VAL_18
  | XLAT_VAL_18
#  endif
#  ifdef XLAT_VAL_19
  | XLAT_VAL_19
#  endif
#  ifdef XLAT_VAL_20
  | XLAT_VAL_20
#  endif
#  ifdef XLAT_VAL_21
  | XLAT_VAL_21
#  endif
#  ifdef XLAT_VAL_22
  | XLAT_VAL_22
#  endif
#  ifdef XLAT_VAL_23
  | XLAT_VAL_23
#  endif
#  ifdef XLAT_VAL_24
  | XLAT_VAL_24
#  endif
#  ifdef XLAT_VAL_25
  | XLAT_VAL_25
#  endif
#  ifdef XLAT_VAL_26
  | XLAT_VAL_26
#  endif
#  ifdef XLAT_VAL_27
  | XLAT_VAL_27
#  endif
#  ifdef XLAT_VAL_28
  | XLAT_VAL_28
#  endif
#  ifdef XLAT_VAL_29
  | XLAT_VAL_29
#  endif
#  ifdef XLAT_VAL_30
  | XLAT_VAL_30
#  endif
#  ifdef XLAT_VAL_31
  | XLAT_VAL_31
#  endif
#  ifdef XLAT_VAL_32
  | XLAT_VAL_32
#  endif
#  ifdef XLAT_VAL_33
  | XLAT_VAL_33
#  endif
#  ifdef XLAT_VAL_34
  | XLAT_VAL_34
#  endif
#  ifdef XLAT_VAL_35
  | XLAT_VAL_35
#  endif
#  ifdef XLAT_VAL_36
  | XLAT_VAL_36
#  endif
#  ifdef XLAT_VAL_37
  | XLAT_VAL_37
#  endif
#  ifdef XLAT_VAL_38
  | XLAT_VAL_38
#  endif
#  ifdef XLAT_VAL_39
  | XLAT_VAL_39
#  endif
#  ifdef XLAT_VAL_40
  | XLAT_VAL_40
#  endif
#  ifdef XLAT_VAL_41
  | XLAT_VAL_41
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
#  ifdef XLAT_STR_15
  + sizeof(XLAT_STR_15)
#  endif
#  ifdef XLAT_STR_16
  + sizeof(XLAT_STR_16)
#  endif
#  ifdef XLAT_STR_17
  + sizeof(XLAT_STR_17)
#  endif
#  ifdef XLAT_STR_18
  + sizeof(XLAT_STR_18)
#  endif
#  ifdef XLAT_STR_19
  + sizeof(XLAT_STR_19)
#  endif
#  ifdef XLAT_STR_20
  + sizeof(XLAT_STR_20)
#  endif
#  ifdef XLAT_STR_21
  + sizeof(XLAT_STR_21)
#  endif
#  ifdef XLAT_STR_22
  + sizeof(XLAT_STR_22)
#  endif
#  ifdef XLAT_STR_23
  + sizeof(XLAT_STR_23)
#  endif
#  ifdef XLAT_STR_24
  + sizeof(XLAT_STR_24)
#  endif
#  ifdef XLAT_STR_25
  + sizeof(XLAT_STR_25)
#  endif
#  ifdef XLAT_STR_26
  + sizeof(XLAT_STR_26)
#  endif
#  ifdef XLAT_STR_27
  + sizeof(XLAT_STR_27)
#  endif
#  ifdef XLAT_STR_28
  + sizeof(XLAT_STR_28)
#  endif
#  ifdef XLAT_STR_29
  + sizeof(XLAT_STR_29)
#  endif
#  ifdef XLAT_STR_30
  + sizeof(XLAT_STR_30)
#  endif
#  ifdef XLAT_STR_31
  + sizeof(XLAT_STR_31)
#  endif
#  ifdef XLAT_STR_32
  + sizeof(XLAT_STR_32)
#  endif
#  ifdef XLAT_STR_33
  + sizeof(XLAT_STR_33)
#  endif
#  ifdef XLAT_STR_34
  + sizeof(XLAT_STR_34)
#  endif
#  ifdef XLAT_STR_35
  + sizeof(XLAT_STR_35)
#  endif
#  ifdef XLAT_STR_36
  + sizeof(XLAT_STR_36)
#  endif
#  ifdef XLAT_STR_37
  + sizeof(XLAT_STR_37)
#  endif
#  ifdef XLAT_STR_38
  + sizeof(XLAT_STR_38)
#  endif
#  ifdef XLAT_STR_39
  + sizeof(XLAT_STR_39)
#  endif
#  ifdef XLAT_STR_40
  + sizeof(XLAT_STR_40)
#  endif
#  ifdef XLAT_STR_41
  + sizeof(XLAT_STR_41)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
#  undef XLAT_STR_15
#  undef XLAT_VAL_15
#  undef XLAT_STR_16
#  undef XLAT_VAL_16
#  undef XLAT_STR_17
#  undef XLAT_VAL_17
#  undef XLAT_STR_18
#  undef XLAT_VAL_18
#  undef XLAT_STR_19
#  undef XLAT_VAL_19
#  undef XLAT_STR_20
#  undef XLAT_VAL_20
#  undef XLAT_STR_21
#  undef XLAT_VAL_21
#  undef XLAT_STR_22
#  undef XLAT_VAL_22
#  undef XLAT_STR_23
#  undef XLAT_VAL_23
#  undef XLAT_STR_24
#  undef XLAT_VAL_24
#  undef XLAT_STR_25
#  undef XLAT_VAL_25
#  undef XLAT_STR_26
#  undef XLAT_VAL_26
#  undef XLAT_STR_27
#  undef XLAT_VAL_27
#  undef XLAT_STR_28
#  undef XLAT_VAL_28
#  undef XLAT_STR_29
#  undef XLAT_VAL_29
#  undef XLAT_STR_30
#  undef XLAT_VAL_30
#  undef XLAT_STR_31
#  undef XLAT_VAL_31
#  undef XLAT_STR_32
#  undef XLAT_VAL_32
#  undef XLAT_STR_33
#  undef XLAT_VAL_33
#  undef XLAT_STR_34
#  undef XLAT_VAL_34
#  undef XLAT_STR_35
#  undef XLAT_VAL_35
#  undef XLAT_STR_36
#  undef XLAT_VAL_36
#  undef XLAT_STR_37
#  undef XLAT_VAL_37
#  undef XLAT_STR_38
#  undef XLAT_VAL_38
#  undef XLAT_STR_39
#  undef XLAT_VAL_39
#  undef XLAT_STR_40
#  undef XLAT_VAL_40
#  undef XLAT_STR_41
#  undef XLAT_VAL_41
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
