/* Generated by ./src/xlat/gen.sh from ./src/xlat/ifstats_af_spec_mpls_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MPLS_STATS_UNSPEC) == (0), "MPLS_STATS_UNSPEC != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MPLS_STATS_LINK) == (1), "MPLS_STATS_LINK != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat ifstats_af_spec_mpls_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data ifstats_af_spec_mpls_attrs_xdata[] = {
 [MPLS_STATS_UNSPEC] = XLAT(MPLS_STATS_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (MPLS_STATS_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(MPLS_STATS_UNSPEC)
 [MPLS_STATS_LINK] = XLAT(MPLS_STATS_LINK),
 #define XLAT_VAL_1 ((unsigned) (MPLS_STATS_LINK))
 #define XLAT_STR_1 STRINGIFY(MPLS_STATS_LINK)
};
static
const struct xlat ifstats_af_spec_mpls_attrs[1] = { {
 .data = ifstats_af_spec_mpls_attrs_xdata,
 .size = ARRAY_SIZE(ifstats_af_spec_mpls_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
