/* Generated by ./src/xlat/gen.sh from ./src/xlat/futexwakecmps.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(FUTEX_OP_CMP_EQ) || (defined(HAVE_DECL_FUTEX_OP_CMP_EQ) && HAVE_DECL_FUTEX_OP_CMP_EQ)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX_OP_CMP_EQ) == (0), "FUTEX_OP_CMP_EQ != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define FUTEX_OP_CMP_EQ 0
#endif
#if defined(FUTEX_OP_CMP_NE) || (defined(HAVE_DECL_FUTEX_OP_CMP_NE) && HAVE_DECL_FUTEX_OP_CMP_NE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX_OP_CMP_NE) == (1), "FUTEX_OP_CMP_NE != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define FUTEX_OP_CMP_NE 1
#endif
#if defined(FUTEX_OP_CMP_LT) || (defined(HAVE_DECL_FUTEX_OP_CMP_LT) && HAVE_DECL_FUTEX_OP_CMP_LT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX_OP_CMP_LT) == (2), "FUTEX_OP_CMP_LT != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define FUTEX_OP_CMP_LT 2
#endif
#if defined(FUTEX_OP_CMP_LE) || (defined(HAVE_DECL_FUTEX_OP_CMP_LE) && HAVE_DECL_FUTEX_OP_CMP_LE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX_OP_CMP_LE) == (3), "FUTEX_OP_CMP_LE != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define FUTEX_OP_CMP_LE 3
#endif
#if defined(FUTEX_OP_CMP_GT) || (defined(HAVE_DECL_FUTEX_OP_CMP_GT) && HAVE_DECL_FUTEX_OP_CMP_GT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX_OP_CMP_GT) == (4), "FUTEX_OP_CMP_GT != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define FUTEX_OP_CMP_GT 4
#endif
#if defined(FUTEX_OP_CMP_GE) || (defined(HAVE_DECL_FUTEX_OP_CMP_GE) && HAVE_DECL_FUTEX_OP_CMP_GE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX_OP_CMP_GE) == (5), "FUTEX_OP_CMP_GE != 5");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define FUTEX_OP_CMP_GE 5
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat futexwakecmps in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data futexwakecmps_xdata[] = {
 [FUTEX_OP_CMP_EQ] = XLAT(FUTEX_OP_CMP_EQ),
 #define XLAT_VAL_0 ((unsigned) (FUTEX_OP_CMP_EQ))
 #define XLAT_STR_0 STRINGIFY(FUTEX_OP_CMP_EQ)
 [FUTEX_OP_CMP_NE] = XLAT(FUTEX_OP_CMP_NE),
 #define XLAT_VAL_1 ((unsigned) (FUTEX_OP_CMP_NE))
 #define XLAT_STR_1 STRINGIFY(FUTEX_OP_CMP_NE)
 [FUTEX_OP_CMP_LT] = XLAT(FUTEX_OP_CMP_LT),
 #define XLAT_VAL_2 ((unsigned) (FUTEX_OP_CMP_LT))
 #define XLAT_STR_2 STRINGIFY(FUTEX_OP_CMP_LT)
 [FUTEX_OP_CMP_LE] = XLAT(FUTEX_OP_CMP_LE),
 #define XLAT_VAL_3 ((unsigned) (FUTEX_OP_CMP_LE))
 #define XLAT_STR_3 STRINGIFY(FUTEX_OP_CMP_LE)
 [FUTEX_OP_CMP_GT] = XLAT(FUTEX_OP_CMP_GT),
 #define XLAT_VAL_4 ((unsigned) (FUTEX_OP_CMP_GT))
 #define XLAT_STR_4 STRINGIFY(FUTEX_OP_CMP_GT)
 [FUTEX_OP_CMP_GE] = XLAT(FUTEX_OP_CMP_GE),
 #define XLAT_VAL_5 ((unsigned) (FUTEX_OP_CMP_GE))
 #define XLAT_STR_5 STRINGIFY(FUTEX_OP_CMP_GE)
};
static
const struct xlat futexwakecmps[1] = { {
 .data = futexwakecmps_xdata,
 .size = ARRAY_SIZE(futexwakecmps_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
