/* Generated by ./src/xlat/gen.sh from ./src/xlat/inet_devconf_indices.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(IPV4_DEVCONF_FORWARDING) || (defined(HAVE_DECL_IPV4_DEVCONF_FORWARDING) && HAVE_DECL_IPV4_DEVCONF_FORWARDING)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_FORWARDING) == (1), "IPV4_DEVCONF_FORWARDING != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_FORWARDING 1
#endif
#if defined(IPV4_DEVCONF_MC_FORWARDING) || (defined(HAVE_DECL_IPV4_DEVCONF_MC_FORWARDING) && HAVE_DECL_IPV4_DEVCONF_MC_FORWARDING)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_MC_FORWARDING) == (2), "IPV4_DEVCONF_MC_FORWARDING != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_MC_FORWARDING 2
#endif
#if defined(IPV4_DEVCONF_PROXY_ARP) || (defined(HAVE_DECL_IPV4_DEVCONF_PROXY_ARP) && HAVE_DECL_IPV4_DEVCONF_PROXY_ARP)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_PROXY_ARP) == (3), "IPV4_DEVCONF_PROXY_ARP != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_PROXY_ARP 3
#endif
#if defined(IPV4_DEVCONF_ACCEPT_REDIRECTS) || (defined(HAVE_DECL_IPV4_DEVCONF_ACCEPT_REDIRECTS) && HAVE_DECL_IPV4_DEVCONF_ACCEPT_REDIRECTS)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_ACCEPT_REDIRECTS) == (4), "IPV4_DEVCONF_ACCEPT_REDIRECTS != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_ACCEPT_REDIRECTS 4
#endif
#if defined(IPV4_DEVCONF_SECURE_REDIRECTS) || (defined(HAVE_DECL_IPV4_DEVCONF_SECURE_REDIRECTS) && HAVE_DECL_IPV4_DEVCONF_SECURE_REDIRECTS)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_SECURE_REDIRECTS) == (5), "IPV4_DEVCONF_SECURE_REDIRECTS != 5");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_SECURE_REDIRECTS 5
#endif
#if defined(IPV4_DEVCONF_SEND_REDIRECTS) || (defined(HAVE_DECL_IPV4_DEVCONF_SEND_REDIRECTS) && HAVE_DECL_IPV4_DEVCONF_SEND_REDIRECTS)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_SEND_REDIRECTS) == (6), "IPV4_DEVCONF_SEND_REDIRECTS != 6");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_SEND_REDIRECTS 6
#endif
#if defined(IPV4_DEVCONF_SHARED_MEDIA) || (defined(HAVE_DECL_IPV4_DEVCONF_SHARED_MEDIA) && HAVE_DECL_IPV4_DEVCONF_SHARED_MEDIA)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_SHARED_MEDIA) == (7), "IPV4_DEVCONF_SHARED_MEDIA != 7");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_SHARED_MEDIA 7
#endif
#if defined(IPV4_DEVCONF_RP_FILTER) || (defined(HAVE_DECL_IPV4_DEVCONF_RP_FILTER) && HAVE_DECL_IPV4_DEVCONF_RP_FILTER)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_RP_FILTER) == (8), "IPV4_DEVCONF_RP_FILTER != 8");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_RP_FILTER 8
#endif
#if defined(IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE) || (defined(HAVE_DECL_IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE) && HAVE_DECL_IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE) == (9), "IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE != 9");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE 9
#endif
#if defined(IPV4_DEVCONF_BOOTP_RELAY) || (defined(HAVE_DECL_IPV4_DEVCONF_BOOTP_RELAY) && HAVE_DECL_IPV4_DEVCONF_BOOTP_RELAY)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_BOOTP_RELAY) == (10), "IPV4_DEVCONF_BOOTP_RELAY != 10");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_BOOTP_RELAY 10
#endif
#if defined(IPV4_DEVCONF_LOG_MARTIANS) || (defined(HAVE_DECL_IPV4_DEVCONF_LOG_MARTIANS) && HAVE_DECL_IPV4_DEVCONF_LOG_MARTIANS)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_LOG_MARTIANS) == (11), "IPV4_DEVCONF_LOG_MARTIANS != 11");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_LOG_MARTIANS 11
#endif
#if defined(IPV4_DEVCONF_TAG) || (defined(HAVE_DECL_IPV4_DEVCONF_TAG) && HAVE_DECL_IPV4_DEVCONF_TAG)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_TAG) == (12), "IPV4_DEVCONF_TAG != 12");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_TAG 12
#endif
#if defined(IPV4_DEVCONF_ARPFILTER) || (defined(HAVE_DECL_IPV4_DEVCONF_ARPFILTER) && HAVE_DECL_IPV4_DEVCONF_ARPFILTER)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_ARPFILTER) == (13), "IPV4_DEVCONF_ARPFILTER != 13");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_ARPFILTER 13
#endif
#if defined(IPV4_DEVCONF_MEDIUM_ID) || (defined(HAVE_DECL_IPV4_DEVCONF_MEDIUM_ID) && HAVE_DECL_IPV4_DEVCONF_MEDIUM_ID)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_MEDIUM_ID) == (14), "IPV4_DEVCONF_MEDIUM_ID != 14");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_MEDIUM_ID 14
#endif
#if defined(IPV4_DEVCONF_NOXFRM) || (defined(HAVE_DECL_IPV4_DEVCONF_NOXFRM) && HAVE_DECL_IPV4_DEVCONF_NOXFRM)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_NOXFRM) == (15), "IPV4_DEVCONF_NOXFRM != 15");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_NOXFRM 15
#endif
#if defined(IPV4_DEVCONF_NOPOLICY) || (defined(HAVE_DECL_IPV4_DEVCONF_NOPOLICY) && HAVE_DECL_IPV4_DEVCONF_NOPOLICY)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_NOPOLICY) == (16), "IPV4_DEVCONF_NOPOLICY != 16");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_NOPOLICY 16
#endif
#if defined(IPV4_DEVCONF_FORCE_IGMP_VERSION) || (defined(HAVE_DECL_IPV4_DEVCONF_FORCE_IGMP_VERSION) && HAVE_DECL_IPV4_DEVCONF_FORCE_IGMP_VERSION)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_FORCE_IGMP_VERSION) == (17), "IPV4_DEVCONF_FORCE_IGMP_VERSION != 17");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_FORCE_IGMP_VERSION 17
#endif
#if defined(IPV4_DEVCONF_ARP_ANNOUNCE) || (defined(HAVE_DECL_IPV4_DEVCONF_ARP_ANNOUNCE) && HAVE_DECL_IPV4_DEVCONF_ARP_ANNOUNCE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_ARP_ANNOUNCE) == (18), "IPV4_DEVCONF_ARP_ANNOUNCE != 18");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_ARP_ANNOUNCE 18
#endif
#if defined(IPV4_DEVCONF_ARP_IGNORE) || (defined(HAVE_DECL_IPV4_DEVCONF_ARP_IGNORE) && HAVE_DECL_IPV4_DEVCONF_ARP_IGNORE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_ARP_IGNORE) == (19), "IPV4_DEVCONF_ARP_IGNORE != 19");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_ARP_IGNORE 19
#endif
#if defined(IPV4_DEVCONF_PROMOTE_SECONDARIES) || (defined(HAVE_DECL_IPV4_DEVCONF_PROMOTE_SECONDARIES) && HAVE_DECL_IPV4_DEVCONF_PROMOTE_SECONDARIES)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_PROMOTE_SECONDARIES) == (20), "IPV4_DEVCONF_PROMOTE_SECONDARIES != 20");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_PROMOTE_SECONDARIES 20
#endif
#if defined(IPV4_DEVCONF_ARP_ACCEPT) || (defined(HAVE_DECL_IPV4_DEVCONF_ARP_ACCEPT) && HAVE_DECL_IPV4_DEVCONF_ARP_ACCEPT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_ARP_ACCEPT) == (21), "IPV4_DEVCONF_ARP_ACCEPT != 21");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_ARP_ACCEPT 21
#endif
#if defined(IPV4_DEVCONF_ARP_NOTIFY) || (defined(HAVE_DECL_IPV4_DEVCONF_ARP_NOTIFY) && HAVE_DECL_IPV4_DEVCONF_ARP_NOTIFY)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_ARP_NOTIFY) == (22), "IPV4_DEVCONF_ARP_NOTIFY != 22");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_ARP_NOTIFY 22
#endif
#if defined(IPV4_DEVCONF_ACCEPT_LOCAL) || (defined(HAVE_DECL_IPV4_DEVCONF_ACCEPT_LOCAL) && HAVE_DECL_IPV4_DEVCONF_ACCEPT_LOCAL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_ACCEPT_LOCAL) == (23), "IPV4_DEVCONF_ACCEPT_LOCAL != 23");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_ACCEPT_LOCAL 23
#endif
#if defined(IPV4_DEVCONF_SRC_VMARK) || (defined(HAVE_DECL_IPV4_DEVCONF_SRC_VMARK) && HAVE_DECL_IPV4_DEVCONF_SRC_VMARK)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_SRC_VMARK) == (24), "IPV4_DEVCONF_SRC_VMARK != 24");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_SRC_VMARK 24
#endif
#if defined(IPV4_DEVCONF_PROXY_ARP_PVLAN) || (defined(HAVE_DECL_IPV4_DEVCONF_PROXY_ARP_PVLAN) && HAVE_DECL_IPV4_DEVCONF_PROXY_ARP_PVLAN)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_PROXY_ARP_PVLAN) == (25), "IPV4_DEVCONF_PROXY_ARP_PVLAN != 25");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_PROXY_ARP_PVLAN 25
#endif
#if defined(IPV4_DEVCONF_ROUTE_LOCALNET) || (defined(HAVE_DECL_IPV4_DEVCONF_ROUTE_LOCALNET) && HAVE_DECL_IPV4_DEVCONF_ROUTE_LOCALNET)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_ROUTE_LOCALNET) == (26), "IPV4_DEVCONF_ROUTE_LOCALNET != 26");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_ROUTE_LOCALNET 26
#endif
#if defined(IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL) || (defined(HAVE_DECL_IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL) && HAVE_DECL_IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL) == (27), "IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL != 27");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL 27
#endif
#if defined(IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL) || (defined(HAVE_DECL_IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL) && HAVE_DECL_IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL) == (28), "IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL != 28");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL 28
#endif
#if defined(IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN) || (defined(HAVE_DECL_IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN) && HAVE_DECL_IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN) == (29), "IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN != 29");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN 29
#endif
#if defined(IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST) || (defined(HAVE_DECL_IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST) && HAVE_DECL_IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST) == (30), "IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST != 30");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST 30
#endif
#if defined(IPV4_DEVCONF_DROP_GRATUITOUS_ARP) || (defined(HAVE_DECL_IPV4_DEVCONF_DROP_GRATUITOUS_ARP) && HAVE_DECL_IPV4_DEVCONF_DROP_GRATUITOUS_ARP)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_DROP_GRATUITOUS_ARP) == (31), "IPV4_DEVCONF_DROP_GRATUITOUS_ARP != 31");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_DROP_GRATUITOUS_ARP 31
#endif
#if defined(IPV4_DEVCONF_BC_FORWARDING) || (defined(HAVE_DECL_IPV4_DEVCONF_BC_FORWARDING) && HAVE_DECL_IPV4_DEVCONF_BC_FORWARDING)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_BC_FORWARDING) == (32), "IPV4_DEVCONF_BC_FORWARDING != 32");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_BC_FORWARDING 32
#endif
#if defined(IPV4_DEVCONF_ARP_EVICT_NOCARRIER) || (defined(HAVE_DECL_IPV4_DEVCONF_ARP_EVICT_NOCARRIER) && HAVE_DECL_IPV4_DEVCONF_ARP_EVICT_NOCARRIER)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPV4_DEVCONF_ARP_EVICT_NOCARRIER) == (33), "IPV4_DEVCONF_ARP_EVICT_NOCARRIER != 33");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPV4_DEVCONF_ARP_EVICT_NOCARRIER 33
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat inet_devconf_indices in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data inet_devconf_indices_xdata[] = {

 [IPV4_DEVCONF_FORWARDING-1] = XLAT(IPV4_DEVCONF_FORWARDING-1),
 #define XLAT_VAL_0 ((unsigned) (IPV4_DEVCONF_FORWARDING-1))
 #define XLAT_STR_0 STRINGIFY(IPV4_DEVCONF_FORWARDING-1)
 [IPV4_DEVCONF_MC_FORWARDING-1] = XLAT(IPV4_DEVCONF_MC_FORWARDING-1),
 #define XLAT_VAL_1 ((unsigned) (IPV4_DEVCONF_MC_FORWARDING-1))
 #define XLAT_STR_1 STRINGIFY(IPV4_DEVCONF_MC_FORWARDING-1)
 [IPV4_DEVCONF_PROXY_ARP-1] = XLAT(IPV4_DEVCONF_PROXY_ARP-1),
 #define XLAT_VAL_2 ((unsigned) (IPV4_DEVCONF_PROXY_ARP-1))
 #define XLAT_STR_2 STRINGIFY(IPV4_DEVCONF_PROXY_ARP-1)
 [IPV4_DEVCONF_ACCEPT_REDIRECTS-1] = XLAT(IPV4_DEVCONF_ACCEPT_REDIRECTS-1),
 #define XLAT_VAL_3 ((unsigned) (IPV4_DEVCONF_ACCEPT_REDIRECTS-1))
 #define XLAT_STR_3 STRINGIFY(IPV4_DEVCONF_ACCEPT_REDIRECTS-1)
 [IPV4_DEVCONF_SECURE_REDIRECTS-1] = XLAT(IPV4_DEVCONF_SECURE_REDIRECTS-1),
 #define XLAT_VAL_4 ((unsigned) (IPV4_DEVCONF_SECURE_REDIRECTS-1))
 #define XLAT_STR_4 STRINGIFY(IPV4_DEVCONF_SECURE_REDIRECTS-1)
 [IPV4_DEVCONF_SEND_REDIRECTS-1] = XLAT(IPV4_DEVCONF_SEND_REDIRECTS-1),
 #define XLAT_VAL_5 ((unsigned) (IPV4_DEVCONF_SEND_REDIRECTS-1))
 #define XLAT_STR_5 STRINGIFY(IPV4_DEVCONF_SEND_REDIRECTS-1)
 [IPV4_DEVCONF_SHARED_MEDIA-1] = XLAT(IPV4_DEVCONF_SHARED_MEDIA-1),
 #define XLAT_VAL_6 ((unsigned) (IPV4_DEVCONF_SHARED_MEDIA-1))
 #define XLAT_STR_6 STRINGIFY(IPV4_DEVCONF_SHARED_MEDIA-1)
 [IPV4_DEVCONF_RP_FILTER-1] = XLAT(IPV4_DEVCONF_RP_FILTER-1),
 #define XLAT_VAL_7 ((unsigned) (IPV4_DEVCONF_RP_FILTER-1))
 #define XLAT_STR_7 STRINGIFY(IPV4_DEVCONF_RP_FILTER-1)
 [IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE-1] = XLAT(IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE-1),
 #define XLAT_VAL_8 ((unsigned) (IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE-1))
 #define XLAT_STR_8 STRINGIFY(IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE-1)
 [IPV4_DEVCONF_BOOTP_RELAY-1] = XLAT(IPV4_DEVCONF_BOOTP_RELAY-1),
 #define XLAT_VAL_9 ((unsigned) (IPV4_DEVCONF_BOOTP_RELAY-1))
 #define XLAT_STR_9 STRINGIFY(IPV4_DEVCONF_BOOTP_RELAY-1)
 [IPV4_DEVCONF_LOG_MARTIANS-1] = XLAT(IPV4_DEVCONF_LOG_MARTIANS-1),
 #define XLAT_VAL_10 ((unsigned) (IPV4_DEVCONF_LOG_MARTIANS-1))
 #define XLAT_STR_10 STRINGIFY(IPV4_DEVCONF_LOG_MARTIANS-1)
 [IPV4_DEVCONF_TAG-1] = XLAT(IPV4_DEVCONF_TAG-1),
 #define XLAT_VAL_11 ((unsigned) (IPV4_DEVCONF_TAG-1))
 #define XLAT_STR_11 STRINGIFY(IPV4_DEVCONF_TAG-1)
 [IPV4_DEVCONF_ARPFILTER-1] = XLAT(IPV4_DEVCONF_ARPFILTER-1),
 #define XLAT_VAL_12 ((unsigned) (IPV4_DEVCONF_ARPFILTER-1))
 #define XLAT_STR_12 STRINGIFY(IPV4_DEVCONF_ARPFILTER-1)
 [IPV4_DEVCONF_MEDIUM_ID-1] = XLAT(IPV4_DEVCONF_MEDIUM_ID-1),
 #define XLAT_VAL_13 ((unsigned) (IPV4_DEVCONF_MEDIUM_ID-1))
 #define XLAT_STR_13 STRINGIFY(IPV4_DEVCONF_MEDIUM_ID-1)
 [IPV4_DEVCONF_NOXFRM-1] = XLAT(IPV4_DEVCONF_NOXFRM-1),
 #define XLAT_VAL_14 ((unsigned) (IPV4_DEVCONF_NOXFRM-1))
 #define XLAT_STR_14 STRINGIFY(IPV4_DEVCONF_NOXFRM-1)
 [IPV4_DEVCONF_NOPOLICY-1] = XLAT(IPV4_DEVCONF_NOPOLICY-1),
 #define XLAT_VAL_15 ((unsigned) (IPV4_DEVCONF_NOPOLICY-1))
 #define XLAT_STR_15 STRINGIFY(IPV4_DEVCONF_NOPOLICY-1)
 [IPV4_DEVCONF_FORCE_IGMP_VERSION-1] = XLAT(IPV4_DEVCONF_FORCE_IGMP_VERSION-1),
 #define XLAT_VAL_16 ((unsigned) (IPV4_DEVCONF_FORCE_IGMP_VERSION-1))
 #define XLAT_STR_16 STRINGIFY(IPV4_DEVCONF_FORCE_IGMP_VERSION-1)
 [IPV4_DEVCONF_ARP_ANNOUNCE-1] = XLAT(IPV4_DEVCONF_ARP_ANNOUNCE-1),
 #define XLAT_VAL_17 ((unsigned) (IPV4_DEVCONF_ARP_ANNOUNCE-1))
 #define XLAT_STR_17 STRINGIFY(IPV4_DEVCONF_ARP_ANNOUNCE-1)
 [IPV4_DEVCONF_ARP_IGNORE-1] = XLAT(IPV4_DEVCONF_ARP_IGNORE-1),
 #define XLAT_VAL_18 ((unsigned) (IPV4_DEVCONF_ARP_IGNORE-1))
 #define XLAT_STR_18 STRINGIFY(IPV4_DEVCONF_ARP_IGNORE-1)
 [IPV4_DEVCONF_PROMOTE_SECONDARIES-1] = XLAT(IPV4_DEVCONF_PROMOTE_SECONDARIES-1),
 #define XLAT_VAL_19 ((unsigned) (IPV4_DEVCONF_PROMOTE_SECONDARIES-1))
 #define XLAT_STR_19 STRINGIFY(IPV4_DEVCONF_PROMOTE_SECONDARIES-1)
 [IPV4_DEVCONF_ARP_ACCEPT-1] = XLAT(IPV4_DEVCONF_ARP_ACCEPT-1),
 #define XLAT_VAL_20 ((unsigned) (IPV4_DEVCONF_ARP_ACCEPT-1))
 #define XLAT_STR_20 STRINGIFY(IPV4_DEVCONF_ARP_ACCEPT-1)
 [IPV4_DEVCONF_ARP_NOTIFY-1] = XLAT(IPV4_DEVCONF_ARP_NOTIFY-1),
 #define XLAT_VAL_21 ((unsigned) (IPV4_DEVCONF_ARP_NOTIFY-1))
 #define XLAT_STR_21 STRINGIFY(IPV4_DEVCONF_ARP_NOTIFY-1)
 [IPV4_DEVCONF_ACCEPT_LOCAL-1] = XLAT(IPV4_DEVCONF_ACCEPT_LOCAL-1),
 #define XLAT_VAL_22 ((unsigned) (IPV4_DEVCONF_ACCEPT_LOCAL-1))
 #define XLAT_STR_22 STRINGIFY(IPV4_DEVCONF_ACCEPT_LOCAL-1)
 [IPV4_DEVCONF_SRC_VMARK-1] = XLAT(IPV4_DEVCONF_SRC_VMARK-1),
 #define XLAT_VAL_23 ((unsigned) (IPV4_DEVCONF_SRC_VMARK-1))
 #define XLAT_STR_23 STRINGIFY(IPV4_DEVCONF_SRC_VMARK-1)
 [IPV4_DEVCONF_PROXY_ARP_PVLAN-1] = XLAT(IPV4_DEVCONF_PROXY_ARP_PVLAN-1),
 #define XLAT_VAL_24 ((unsigned) (IPV4_DEVCONF_PROXY_ARP_PVLAN-1))
 #define XLAT_STR_24 STRINGIFY(IPV4_DEVCONF_PROXY_ARP_PVLAN-1)
 [IPV4_DEVCONF_ROUTE_LOCALNET-1] = XLAT(IPV4_DEVCONF_ROUTE_LOCALNET-1),
 #define XLAT_VAL_25 ((unsigned) (IPV4_DEVCONF_ROUTE_LOCALNET-1))
 #define XLAT_STR_25 STRINGIFY(IPV4_DEVCONF_ROUTE_LOCALNET-1)
 [IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL-1] = XLAT(IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL-1),
 #define XLAT_VAL_26 ((unsigned) (IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL-1))
 #define XLAT_STR_26 STRINGIFY(IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL-1)
 [IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL-1] = XLAT(IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL-1),
 #define XLAT_VAL_27 ((unsigned) (IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL-1))
 #define XLAT_STR_27 STRINGIFY(IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL-1)
 [IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN-1] = XLAT(IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN-1),
 #define XLAT_VAL_28 ((unsigned) (IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN-1))
 #define XLAT_STR_28 STRINGIFY(IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN-1)
 [IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST-1] = XLAT(IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST-1),
 #define XLAT_VAL_29 ((unsigned) (IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST-1))
 #define XLAT_STR_29 STRINGIFY(IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST-1)
 [IPV4_DEVCONF_DROP_GRATUITOUS_ARP-1] = XLAT(IPV4_DEVCONF_DROP_GRATUITOUS_ARP-1),
 #define XLAT_VAL_30 ((unsigned) (IPV4_DEVCONF_DROP_GRATUITOUS_ARP-1))
 #define XLAT_STR_30 STRINGIFY(IPV4_DEVCONF_DROP_GRATUITOUS_ARP-1)
 [IPV4_DEVCONF_BC_FORWARDING-1] = XLAT(IPV4_DEVCONF_BC_FORWARDING-1),
 #define XLAT_VAL_31 ((unsigned) (IPV4_DEVCONF_BC_FORWARDING-1))
 #define XLAT_STR_31 STRINGIFY(IPV4_DEVCONF_BC_FORWARDING-1)
 [IPV4_DEVCONF_ARP_EVICT_NOCARRIER-1] = XLAT(IPV4_DEVCONF_ARP_EVICT_NOCARRIER-1),
 #define XLAT_VAL_32 ((unsigned) (IPV4_DEVCONF_ARP_EVICT_NOCARRIER-1))
 #define XLAT_STR_32 STRINGIFY(IPV4_DEVCONF_ARP_EVICT_NOCARRIER-1)
};
static
const struct xlat inet_devconf_indices[1] = { {
 .data = inet_devconf_indices_xdata,
 .size = ARRAY_SIZE(inet_devconf_indices_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
#  ifdef XLAT_VAL_15
  | XLAT_VAL_15
#  endif
#  ifdef XLAT_VAL_16
  | XLAT_VAL_16
#  endif
#  ifdef XLAT_VAL_17
  | XLAT_VAL_17
#  endif
#  ifdef XLAT_VAL_18
  | XLAT_VAL_18
#  endif
#  ifdef XLAT_VAL_19
  | XLAT_VAL_19
#  endif
#  ifdef XLAT_VAL_20
  | XLAT_VAL_20
#  endif
#  ifdef XLAT_VAL_21
  | XLAT_VAL_21
#  endif
#  ifdef XLAT_VAL_22
  | XLAT_VAL_22
#  endif
#  ifdef XLAT_VAL_23
  | XLAT_VAL_23
#  endif
#  ifdef XLAT_VAL_24
  | XLAT_VAL_24
#  endif
#  ifdef XLAT_VAL_25
  | XLAT_VAL_25
#  endif
#  ifdef XLAT_VAL_26
  | XLAT_VAL_26
#  endif
#  ifdef XLAT_VAL_27
  | XLAT_VAL_27
#  endif
#  ifdef XLAT_VAL_28
  | XLAT_VAL_28
#  endif
#  ifdef XLAT_VAL_29
  | XLAT_VAL_29
#  endif
#  ifdef XLAT_VAL_30
  | XLAT_VAL_30
#  endif
#  ifdef XLAT_VAL_31
  | XLAT_VAL_31
#  endif
#  ifdef XLAT_VAL_32
  | XLAT_VAL_32
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
#  ifdef XLAT_STR_15
  + sizeof(XLAT_STR_15)
#  endif
#  ifdef XLAT_STR_16
  + sizeof(XLAT_STR_16)
#  endif
#  ifdef XLAT_STR_17
  + sizeof(XLAT_STR_17)
#  endif
#  ifdef XLAT_STR_18
  + sizeof(XLAT_STR_18)
#  endif
#  ifdef XLAT_STR_19
  + sizeof(XLAT_STR_19)
#  endif
#  ifdef XLAT_STR_20
  + sizeof(XLAT_STR_20)
#  endif
#  ifdef XLAT_STR_21
  + sizeof(XLAT_STR_21)
#  endif
#  ifdef XLAT_STR_22
  + sizeof(XLAT_STR_22)
#  endif
#  ifdef XLAT_STR_23
  + sizeof(XLAT_STR_23)
#  endif
#  ifdef XLAT_STR_24
  + sizeof(XLAT_STR_24)
#  endif
#  ifdef XLAT_STR_25
  + sizeof(XLAT_STR_25)
#  endif
#  ifdef XLAT_STR_26
  + sizeof(XLAT_STR_26)
#  endif
#  ifdef XLAT_STR_27
  + sizeof(XLAT_STR_27)
#  endif
#  ifdef XLAT_STR_28
  + sizeof(XLAT_STR_28)
#  endif
#  ifdef XLAT_STR_29
  + sizeof(XLAT_STR_29)
#  endif
#  ifdef XLAT_STR_30
  + sizeof(XLAT_STR_30)
#  endif
#  ifdef XLAT_STR_31
  + sizeof(XLAT_STR_31)
#  endif
#  ifdef XLAT_STR_32
  + sizeof(XLAT_STR_32)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
#  undef XLAT_STR_15
#  undef XLAT_VAL_15
#  undef XLAT_STR_16
#  undef XLAT_VAL_16
#  undef XLAT_STR_17
#  undef XLAT_VAL_17
#  undef XLAT_STR_18
#  undef XLAT_VAL_18
#  undef XLAT_STR_19
#  undef XLAT_VAL_19
#  undef XLAT_STR_20
#  undef XLAT_VAL_20
#  undef XLAT_STR_21
#  undef XLAT_VAL_21
#  undef XLAT_STR_22
#  undef XLAT_VAL_22
#  undef XLAT_STR_23
#  undef XLAT_VAL_23
#  undef XLAT_STR_24
#  undef XLAT_VAL_24
#  undef XLAT_STR_25
#  undef XLAT_VAL_25
#  undef XLAT_STR_26
#  undef XLAT_VAL_26
#  undef XLAT_STR_27
#  undef XLAT_VAL_27
#  undef XLAT_STR_28
#  undef XLAT_VAL_28
#  undef XLAT_STR_29
#  undef XLAT_VAL_29
#  undef XLAT_STR_30
#  undef XLAT_VAL_30
#  undef XLAT_STR_31
#  undef XLAT_VAL_31
#  undef XLAT_STR_32
#  undef XLAT_VAL_32
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
