/* Generated by ./src/xlat/gen.sh from ./src/xlat/seccomp_ret_action.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifndef IN_MPERS

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data seccomp_ret_action_xdata[] = {
 XLAT(SECCOMP_RET_KILL_PROCESS),
 #define XLAT_VAL_0 ((unsigned) (SECCOMP_RET_KILL_PROCESS))
 #define XLAT_STR_0 STRINGIFY(SECCOMP_RET_KILL_PROCESS)
 XLAT(SECCOMP_RET_KILL_THREAD),
 #define XLAT_VAL_1 ((unsigned) (SECCOMP_RET_KILL_THREAD))
 #define XLAT_STR_1 STRINGIFY(SECCOMP_RET_KILL_THREAD)
 XLAT(SECCOMP_RET_TRAP),
 #define XLAT_VAL_2 ((unsigned) (SECCOMP_RET_TRAP))
 #define XLAT_STR_2 STRINGIFY(SECCOMP_RET_TRAP)
 XLAT(SECCOMP_RET_ERRNO),
 #define XLAT_VAL_3 ((unsigned) (SECCOMP_RET_ERRNO))
 #define XLAT_STR_3 STRINGIFY(SECCOMP_RET_ERRNO)
 XLAT(SECCOMP_RET_USER_NOTIF),
 #define XLAT_VAL_4 ((unsigned) (SECCOMP_RET_USER_NOTIF))
 #define XLAT_STR_4 STRINGIFY(SECCOMP_RET_USER_NOTIF)
 XLAT(SECCOMP_RET_TRACE),
 #define XLAT_VAL_5 ((unsigned) (SECCOMP_RET_TRACE))
 #define XLAT_STR_5 STRINGIFY(SECCOMP_RET_TRACE)
 XLAT(SECCOMP_RET_LOG),
 #define XLAT_VAL_6 ((unsigned) (SECCOMP_RET_LOG))
 #define XLAT_STR_6 STRINGIFY(SECCOMP_RET_LOG)
 XLAT(SECCOMP_RET_ALLOW),
 #define XLAT_VAL_7 ((unsigned) (SECCOMP_RET_ALLOW))
 #define XLAT_STR_7 STRINGIFY(SECCOMP_RET_ALLOW)
};
const struct xlat seccomp_ret_action[1] = { {
 .data = seccomp_ret_action_xdata,
 .size = ARRAY_SIZE(seccomp_ret_action_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
