/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_tca_act_hw_stats.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(TCA_ACT_HW_STATS_IMMEDIATE) || (defined(HAVE_DECL_TCA_ACT_HW_STATS_IMMEDIATE) && HAVE_DECL_TCA_ACT_HW_STATS_IMMEDIATE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((TCA_ACT_HW_STATS_IMMEDIATE) == ((1<<0)), "TCA_ACT_HW_STATS_IMMEDIATE != (1<<0)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define TCA_ACT_HW_STATS_IMMEDIATE (1<<0)
#endif
#if defined(TCA_ACT_HW_STATS_DELAYED) || (defined(HAVE_DECL_TCA_ACT_HW_STATS_DELAYED) && HAVE_DECL_TCA_ACT_HW_STATS_DELAYED)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((TCA_ACT_HW_STATS_DELAYED) == ((1<<1)), "TCA_ACT_HW_STATS_DELAYED != (1<<1)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define TCA_ACT_HW_STATS_DELAYED (1<<1)
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_tca_act_hw_stats in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_tca_act_hw_stats_xdata[] = {
 XLAT(TCA_ACT_HW_STATS_IMMEDIATE),
 #define XLAT_VAL_0 ((unsigned) (TCA_ACT_HW_STATS_IMMEDIATE))
 #define XLAT_STR_0 STRINGIFY(TCA_ACT_HW_STATS_IMMEDIATE)
 XLAT(TCA_ACT_HW_STATS_DELAYED),
 #define XLAT_VAL_1 ((unsigned) (TCA_ACT_HW_STATS_DELAYED))
 #define XLAT_STR_1 STRINGIFY(TCA_ACT_HW_STATS_DELAYED)
};
static
const struct xlat rtnl_tca_act_hw_stats[1] = { {
 .data = rtnl_tca_act_hw_stats_xdata,
 .size = ARRAY_SIZE(rtnl_tca_act_hw_stats_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
