/* Generated by ./src/xlat/gen.sh from ./src/xlat/af_packet_types.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(PACKET_HOST) || (defined(HAVE_DECL_PACKET_HOST) && HAVE_DECL_PACKET_HOST)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PACKET_HOST) == (0), "PACKET_HOST != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PACKET_HOST 0
#endif
#if defined(PACKET_BROADCAST) || (defined(HAVE_DECL_PACKET_BROADCAST) && HAVE_DECL_PACKET_BROADCAST)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PACKET_BROADCAST) == (1), "PACKET_BROADCAST != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PACKET_BROADCAST 1
#endif
#if defined(PACKET_MULTICAST) || (defined(HAVE_DECL_PACKET_MULTICAST) && HAVE_DECL_PACKET_MULTICAST)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PACKET_MULTICAST) == (2), "PACKET_MULTICAST != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PACKET_MULTICAST 2
#endif
#if defined(PACKET_OTHERHOST) || (defined(HAVE_DECL_PACKET_OTHERHOST) && HAVE_DECL_PACKET_OTHERHOST)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PACKET_OTHERHOST) == (3), "PACKET_OTHERHOST != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PACKET_OTHERHOST 3
#endif
#if defined(PACKET_OUTGOING) || (defined(HAVE_DECL_PACKET_OUTGOING) && HAVE_DECL_PACKET_OUTGOING)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PACKET_OUTGOING) == (4), "PACKET_OUTGOING != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PACKET_OUTGOING 4
#endif
#if defined(PACKET_LOOPBACK) || (defined(HAVE_DECL_PACKET_LOOPBACK) && HAVE_DECL_PACKET_LOOPBACK)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PACKET_LOOPBACK) == (5), "PACKET_LOOPBACK != 5");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PACKET_LOOPBACK 5
#endif
#if defined(PACKET_USER) || (defined(HAVE_DECL_PACKET_USER) && HAVE_DECL_PACKET_USER)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PACKET_USER) == (6), "PACKET_USER != 6");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PACKET_USER 6
#endif
#if defined(PACKET_KERNEL) || (defined(HAVE_DECL_PACKET_KERNEL) && HAVE_DECL_PACKET_KERNEL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PACKET_KERNEL) == (7), "PACKET_KERNEL != 7");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PACKET_KERNEL 7
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat af_packet_types in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data af_packet_types_xdata[] = {
 [PACKET_HOST] = XLAT(PACKET_HOST),
 #define XLAT_VAL_0 ((unsigned) (PACKET_HOST))
 #define XLAT_STR_0 STRINGIFY(PACKET_HOST)
 [PACKET_BROADCAST] = XLAT(PACKET_BROADCAST),
 #define XLAT_VAL_1 ((unsigned) (PACKET_BROADCAST))
 #define XLAT_STR_1 STRINGIFY(PACKET_BROADCAST)
 [PACKET_MULTICAST] = XLAT(PACKET_MULTICAST),
 #define XLAT_VAL_2 ((unsigned) (PACKET_MULTICAST))
 #define XLAT_STR_2 STRINGIFY(PACKET_MULTICAST)
 [PACKET_OTHERHOST] = XLAT(PACKET_OTHERHOST),
 #define XLAT_VAL_3 ((unsigned) (PACKET_OTHERHOST))
 #define XLAT_STR_3 STRINGIFY(PACKET_OTHERHOST)
 [PACKET_OUTGOING] = XLAT(PACKET_OUTGOING),
 #define XLAT_VAL_4 ((unsigned) (PACKET_OUTGOING))
 #define XLAT_STR_4 STRINGIFY(PACKET_OUTGOING)
 [PACKET_LOOPBACK] = XLAT(PACKET_LOOPBACK),
 #define XLAT_VAL_5 ((unsigned) (PACKET_LOOPBACK))
 #define XLAT_STR_5 STRINGIFY(PACKET_LOOPBACK)
 [PACKET_USER] = XLAT(PACKET_USER),
 #define XLAT_VAL_6 ((unsigned) (PACKET_USER))
 #define XLAT_STR_6 STRINGIFY(PACKET_USER)
 [PACKET_KERNEL] = XLAT(PACKET_KERNEL),
 #define XLAT_VAL_7 ((unsigned) (PACKET_KERNEL))
 #define XLAT_STR_7 STRINGIFY(PACKET_KERNEL)
};
static
const struct xlat af_packet_types[1] = { {
 .data = af_packet_types_xdata,
 .size = ARRAY_SIZE(af_packet_types_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
