/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_ifla_af_spec_inet6_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_ifla_af_spec_inet6_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_ifla_af_spec_inet6_attrs_xdata[] = {
 [IFLA_INET6_UNSPEC] = XLAT(IFLA_INET6_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (IFLA_INET6_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(IFLA_INET6_UNSPEC)
 [IFLA_INET6_FLAGS] = XLAT(IFLA_INET6_FLAGS),
 #define XLAT_VAL_1 ((unsigned) (IFLA_INET6_FLAGS))
 #define XLAT_STR_1 STRINGIFY(IFLA_INET6_FLAGS)
 [IFLA_INET6_CONF] = XLAT(IFLA_INET6_CONF),
 #define XLAT_VAL_2 ((unsigned) (IFLA_INET6_CONF))
 #define XLAT_STR_2 STRINGIFY(IFLA_INET6_CONF)
 [IFLA_INET6_STATS] = XLAT(IFLA_INET6_STATS),
 #define XLAT_VAL_3 ((unsigned) (IFLA_INET6_STATS))
 #define XLAT_STR_3 STRINGIFY(IFLA_INET6_STATS)
 [IFLA_INET6_MCAST] = XLAT(IFLA_INET6_MCAST),
 #define XLAT_VAL_4 ((unsigned) (IFLA_INET6_MCAST))
 #define XLAT_STR_4 STRINGIFY(IFLA_INET6_MCAST)
 [IFLA_INET6_CACHEINFO] = XLAT(IFLA_INET6_CACHEINFO),
 #define XLAT_VAL_5 ((unsigned) (IFLA_INET6_CACHEINFO))
 #define XLAT_STR_5 STRINGIFY(IFLA_INET6_CACHEINFO)
 [IFLA_INET6_ICMP6STATS] = XLAT(IFLA_INET6_ICMP6STATS),
 #define XLAT_VAL_6 ((unsigned) (IFLA_INET6_ICMP6STATS))
 #define XLAT_STR_6 STRINGIFY(IFLA_INET6_ICMP6STATS)
 [IFLA_INET6_TOKEN] = XLAT(IFLA_INET6_TOKEN),
 #define XLAT_VAL_7 ((unsigned) (IFLA_INET6_TOKEN))
 #define XLAT_STR_7 STRINGIFY(IFLA_INET6_TOKEN)
 [IFLA_INET6_ADDR_GEN_MODE] = XLAT(IFLA_INET6_ADDR_GEN_MODE),
 #define XLAT_VAL_8 ((unsigned) (IFLA_INET6_ADDR_GEN_MODE))
 #define XLAT_STR_8 STRINGIFY(IFLA_INET6_ADDR_GEN_MODE)
 [IFLA_INET6_RA_MTU] = XLAT(IFLA_INET6_RA_MTU),
 #define XLAT_VAL_9 ((unsigned) (IFLA_INET6_RA_MTU))
 #define XLAT_STR_9 STRINGIFY(IFLA_INET6_RA_MTU)
};
static
const struct xlat rtnl_ifla_af_spec_inet6_attrs[1] = { {
 .data = rtnl_ifla_af_spec_inet6_attrs_xdata,
 .size = ARRAY_SIZE(rtnl_ifla_af_spec_inet6_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
