/* src/config.h.  Generated from config.h.in by configure.  */
/* src/config.h.in.  Generated from configure.ac by autoheader.  */

/* Define for the AArch64 architecture. */
/* #undef AARCH64 */

/* Define if building universal (internal helper macro) */
/* #undef AC_APPLE_UNIVERSAL_BUILD */

/* Define for the Alpha architecture. */
/* #undef ALPHA */

/* Define for the ARC architecture. */
/* #undef ARC */

/* Define for the ARM architecture. */
#define ARM 1

/* SA_RESTORER defined in <asm/signal.h> */
#define ASM_SA_RESTORER 0x04000000

/* SIGRTMIN defined in <asm/signal.h> */
#define ASM_SIGRTMIN 32

/* Define for the AVR32 architecture. */
/* #undef AVR32 */

/* Define for the Blackfin architecture. */
/* #undef BFIN */

/* Current copyright year. */
#define COPYRIGHT_YEAR "2022"

/* Define for the C-SKY architecture */
/* #undef CSKY */

/* Define to 1 if you want OABI support on ARM EABI. */
#define ENABLE_ARM_OABI 0

/* Define to enable SELinux security contexts support */
/* #undef ENABLE_SECONTEXT */

/* Define to enable stack tracing support */
/* #undef ENABLE_STACKTRACE */

/* Define to 1 if you have the `accept4' function. */
#define HAVE_ACCEPT4 1

/* Define to 1 if you have the <asm/cachectl.h> header file. */
/* #undef HAVE_ASM_CACHECTL_H */

/* Define to 1 if you have the <asm/guarded_storage.h> header file. */
/* #undef HAVE_ASM_GUARDED_STORAGE_H */

/* Define to 1 if you have the <asm/sigcontext.h> header file. */
#define HAVE_ASM_SIGCONTEXT_H 1

/* Define to 1 if you have the <asm/sysmips.h> header file. */
/* #undef HAVE_ASM_SYSMIPS_H */

/* Define to 1 if you have the `be64toh' function. */
/* #undef HAVE_BE64TOH */

/* Define to 1 if you have the <bluetooth/bluetooth.h> header file. */
#define HAVE_BLUETOOTH_BLUETOOTH_H 1

/* Define to 1 if you have the declaration of `CTL_ABI', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_ABI 1

/* Define to 1 if you have the declaration of `CTL_APPLDATA', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_APPLDATA 0

/* Define to 1 if you have the declaration of `CTL_ARLAN', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_ARLAN 1

/* Define to 1 if you have the declaration of `CTL_BUS', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_BUS 1

/* Define to 1 if you have the declaration of `CTL_CPU', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_CPU 1

/* Define to 1 if you have the declaration of `CTL_DEBUG', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_DEBUG 1

/* Define to 1 if you have the declaration of `CTL_DEV', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_DEV 1

/* Define to 1 if you have the declaration of `CTL_FRV', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_FRV 1

/* Define to 1 if you have the declaration of `CTL_FS', and to 0 if you don't.
   */
#define HAVE_DECL_CTL_FS 1

/* Define to 1 if you have the declaration of `CTL_INOTIFY', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_INOTIFY 0

/* Define to 1 if you have the declaration of `CTL_KERN', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_KERN 1

/* Define to 1 if you have the declaration of `CTL_NET', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_NET 1

/* Define to 1 if you have the declaration of `CTL_PM', and to 0 if you don't.
   */
#define HAVE_DECL_CTL_PM 1

/* Define to 1 if you have the declaration of `CTL_PROC', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_PROC 1

/* Define to 1 if you have the declaration of `CTL_S390DBF', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_S390DBF 1

/* Define to 1 if you have the declaration of `CTL_SUNRPC', and to 0 if you
   don't. */
#define HAVE_DECL_CTL_SUNRPC 1

/* Define to 1 if you have the declaration of `CTL_VM', and to 0 if you don't.
   */
#define HAVE_DECL_CTL_VM 1

/* Define to 1 if you have the declaration of `IEEE802154_ADDR_LONG', and to 0
   if you don't. */
#define HAVE_DECL_IEEE802154_ADDR_LONG 0

/* Define to 1 if you have the declaration of `IEEE802154_ADDR_NONE', and to 0
   if you don't. */
#define HAVE_DECL_IEEE802154_ADDR_NONE 0

/* Define to 1 if you have the declaration of `IEEE802154_ADDR_SHORT', and to
   0 if you don't. */
#define HAVE_DECL_IEEE802154_ADDR_SHORT 0

/* Define to 1 if you have the declaration of `KERN_ACCT', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_ACCT 1

/* Define to 1 if you have the declaration of `KERN_ACPI_VIDEO_FLAGS', and to
   0 if you don't. */
#define HAVE_DECL_KERN_ACPI_VIDEO_FLAGS 1

/* Define to 1 if you have the declaration of `KERN_BOOTLOADER_TYPE', and to 0
   if you don't. */
#define HAVE_DECL_KERN_BOOTLOADER_TYPE 1

/* Define to 1 if you have the declaration of `KERN_CADPID', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_CADPID 1

/* Define to 1 if you have the declaration of `KERN_CAP_BSET', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_CAP_BSET 0

/* Define to 1 if you have the declaration of `KERN_COMPAT_LOG', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_COMPAT_LOG 1

/* Define to 1 if you have the declaration of `KERN_CORE_PATTERN', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_CORE_PATTERN 1

/* Define to 1 if you have the declaration of `KERN_CORE_USES_PID', and to 0
   if you don't. */
#define HAVE_DECL_KERN_CORE_USES_PID 1

/* Define to 1 if you have the declaration of `KERN_CTLALTDEL', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_CTLALTDEL 1

/* Define to 1 if you have the declaration of `KERN_DOMAINNAME', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_DOMAINNAME 1

/* Define to 1 if you have the declaration of `KERN_HOTPLUG', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_HOTPLUG 1

/* Define to 1 if you have the declaration of `KERN_HPPA_PWRSW', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_HPPA_PWRSW 1

/* Define to 1 if you have the declaration of `KERN_HPPA_UNALIGNED', and to 0
   if you don't. */
#define HAVE_DECL_KERN_HPPA_UNALIGNED 1

/* Define to 1 if you have the declaration of `KERN_HZ_TIMER', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_HZ_TIMER 1

/* Define to 1 if you have the declaration of `KERN_IA64_UNALIGNED', and to 0
   if you don't. */
#define HAVE_DECL_KERN_IA64_UNALIGNED 1

/* Define to 1 if you have the declaration of `KERN_IEEE_EMULATION_WARNINGS',
   and to 0 if you don't. */
#define HAVE_DECL_KERN_IEEE_EMULATION_WARNINGS 1

/* Define to 1 if you have the declaration of `KERN_JAVA_APPLETVIEWER', and to
   0 if you don't. */
#define HAVE_DECL_KERN_JAVA_APPLETVIEWER 0

/* Define to 1 if you have the declaration of `KERN_JAVA_INTERPRETER', and to
   0 if you don't. */
#define HAVE_DECL_KERN_JAVA_INTERPRETER 0

/* Define to 1 if you have the declaration of `KERN_MAXFILE', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_MAXFILE 0

/* Define to 1 if you have the declaration of `KERN_MAXID', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_MAXID 0

/* Define to 1 if you have the declaration of `KERN_MAXINODE', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_MAXINODE 0

/* Define to 1 if you have the declaration of `KERN_MAX_LOCK_DEPTH', and to 0
   if you don't. */
#define HAVE_DECL_KERN_MAX_LOCK_DEPTH 1

/* Define to 1 if you have the declaration of `KERN_MAX_THREADS', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_MAX_THREADS 1

/* Define to 1 if you have the declaration of `KERN_MODPROBE', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_MODPROBE 1

/* Define to 1 if you have the declaration of `KERN_MSGMAX', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_MSGMAX 1

/* Define to 1 if you have the declaration of `KERN_MSGMNB', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_MSGMNB 1

/* Define to 1 if you have the declaration of `KERN_MSGMNI', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_MSGMNI 1

/* Define to 1 if you have the declaration of `KERN_MSGPOOL', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_MSGPOOL 1

/* Define to 1 if you have the declaration of `KERN_NAMETRANS', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_NAMETRANS 1

/* Define to 1 if you have the declaration of `KERN_NFSRADDRS', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_NFSRADDRS 0

/* Define to 1 if you have the declaration of `KERN_NFSRNAME', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_NFSRNAME 0

/* Define to 1 if you have the declaration of `KERN_NGROUPS_MAX', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_NGROUPS_MAX 1

/* Define to 1 if you have the declaration of `KERN_NMI_WATCHDOG', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_NMI_WATCHDOG 1

/* Define to 1 if you have the declaration of `KERN_NODENAME', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_NODENAME 1

/* Define to 1 if you have the declaration of `KERN_NRFILE', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_NRFILE 0

/* Define to 1 if you have the declaration of `KERN_NRINODE', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_NRINODE 0

/* Define to 1 if you have the declaration of `KERN_OSRELEASE', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_OSRELEASE 1

/* Define to 1 if you have the declaration of `KERN_OSREV', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_OSREV 1

/* Define to 1 if you have the declaration of `KERN_OSTYPE', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_OSTYPE 1

/* Define to 1 if you have the declaration of `KERN_OVERFLOWGID', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_OVERFLOWGID 1

/* Define to 1 if you have the declaration of `KERN_OVERFLOWUID', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_OVERFLOWUID 1

/* Define to 1 if you have the declaration of `KERN_PANIC', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_PANIC 1

/* Define to 1 if you have the declaration of `KERN_PANIC_ON_NMI', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_PANIC_ON_NMI 1

/* Define to 1 if you have the declaration of `KERN_PANIC_ON_OOPS', and to 0
   if you don't. */
#define HAVE_DECL_KERN_PANIC_ON_OOPS 1

/* Define to 1 if you have the declaration of `KERN_PANIC_ON_WARN', and to 0
   if you don't. */
#define HAVE_DECL_KERN_PANIC_ON_WARN 1

/* Define to 1 if you have the declaration of `KERN_PIDMAX', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_PIDMAX 1

/* Define to 1 if you have the declaration of `KERN_PPC_HTABRECLAIM', and to 0
   if you don't. */
#define HAVE_DECL_KERN_PPC_HTABRECLAIM 1

/* Define to 1 if you have the declaration of `KERN_PPC_L2CR', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_PPC_L2CR 1

/* Define to 1 if you have the declaration of `KERN_PPC_POWERSAVE_NAP', and to
   0 if you don't. */
#define HAVE_DECL_KERN_PPC_POWERSAVE_NAP 1

/* Define to 1 if you have the declaration of `KERN_PPC_ZEROPAGED', and to 0
   if you don't. */
#define HAVE_DECL_KERN_PPC_ZEROPAGED 1

/* Define to 1 if you have the declaration of `KERN_PRINTK', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_PRINTK 1

/* Define to 1 if you have the declaration of `KERN_PRINTK_RATELIMIT', and to
   0 if you don't. */
#define HAVE_DECL_KERN_PRINTK_RATELIMIT 1

/* Define to 1 if you have the declaration of `KERN_PRINTK_RATELIMIT_BURST',
   and to 0 if you don't. */
#define HAVE_DECL_KERN_PRINTK_RATELIMIT_BURST 1

/* Define to 1 if you have the declaration of `KERN_PROF', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_PROF 1

/* Define to 1 if you have the declaration of `KERN_PTY', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_PTY 1

/* Define to 1 if you have the declaration of `KERN_RANDOM', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_RANDOM 1

/* Define to 1 if you have the declaration of `KERN_RANDOMIZE', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_RANDOMIZE 1

/* Define to 1 if you have the declaration of `KERN_REALROOTDEV', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_REALROOTDEV 1

/* Define to 1 if you have the declaration of `KERN_RTSIGMAX', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_RTSIGMAX 1

/* Define to 1 if you have the declaration of `KERN_RTSIGNR', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_RTSIGNR 1

/* Define to 1 if you have the declaration of `KERN_S390_USER_DEBUG_LOGGING',
   and to 0 if you don't. */
#define HAVE_DECL_KERN_S390_USER_DEBUG_LOGGING 1

/* Define to 1 if you have the declaration of `KERN_SECUREMASK', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_SECUREMASK 1

/* Define to 1 if you have the declaration of `KERN_SEM', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_SEM 1

/* Define to 1 if you have the declaration of `KERN_SETUID_DUMPABLE', and to 0
   if you don't. */
#define HAVE_DECL_KERN_SETUID_DUMPABLE 1

/* Define to 1 if you have the declaration of `KERN_SG_BIG_BUFF', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_SG_BIG_BUFF 1

/* Define to 1 if you have the declaration of `KERN_SHMALL', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_SHMALL 1

/* Define to 1 if you have the declaration of `KERN_SHMMAX', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_SHMMAX 1

/* Define to 1 if you have the declaration of `KERN_SHMMNI', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_SHMMNI 1

/* Define to 1 if you have the declaration of `KERN_SHMPATH', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_SHMPATH 1

/* Define to 1 if you have the declaration of `KERN_SPARC_REBOOT', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_SPARC_REBOOT 1

/* Define to 1 if you have the declaration of `KERN_SPARC_SCONS_PWROFF', and
   to 0 if you don't. */
#define HAVE_DECL_KERN_SPARC_SCONS_PWROFF 1

/* Define to 1 if you have the declaration of `KERN_SPARC_STOP_A', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_SPARC_STOP_A 1

/* Define to 1 if you have the declaration of `KERN_SPIN_RETRY', and to 0 if
   you don't. */
#define HAVE_DECL_KERN_SPIN_RETRY 1

/* Define to 1 if you have the declaration of `KERN_SYSRQ', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_SYSRQ 1

/* Define to 1 if you have the declaration of `KERN_TAINTED', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_TAINTED 1

/* Define to 1 if you have the declaration of `KERN_UNKNOWN_NMI_PANIC', and to
   0 if you don't. */
#define HAVE_DECL_KERN_UNKNOWN_NMI_PANIC 1

/* Define to 1 if you have the declaration of `KERN_VERSION', and to 0 if you
   don't. */
#define HAVE_DECL_KERN_VERSION 1

/* Define to 1 if you have the declaration of `LO_FLAGS_AUTOCLEAR', and to 0
   if you don't. */
#define HAVE_DECL_LO_FLAGS_AUTOCLEAR 1

/* Define to 1 if you have the declaration of `LO_FLAGS_DIRECT_IO', and to 0
   if you don't. */
#define HAVE_DECL_LO_FLAGS_DIRECT_IO 1

/* Define to 1 if you have the declaration of `LO_FLAGS_PARTSCAN', and to 0 if
   you don't. */
#define HAVE_DECL_LO_FLAGS_PARTSCAN 1

/* Define to 1 if you have the declaration of `LO_FLAGS_READ_ONLY', and to 0
   if you don't. */
#define HAVE_DECL_LO_FLAGS_READ_ONLY 1

/* Define to 1 if you have the declaration of `LO_FLAGS_USE_AOPS', and to 0 if
   you don't. */
#define HAVE_DECL_LO_FLAGS_USE_AOPS 0

/* Define to 1 if you have the declaration of `NET_802', and to 0 if you
   don't. */
#define HAVE_DECL_NET_802 1

/* Define to 1 if you have the declaration of `NET_ATALK', and to 0 if you
   don't. */
#define HAVE_DECL_NET_ATALK 1

/* Define to 1 if you have the declaration of `NET_AX25', and to 0 if you
   don't. */
#define HAVE_DECL_NET_AX25 1

/* Define to 1 if you have the declaration of `NET_BRIDGE', and to 0 if you
   don't. */
#define HAVE_DECL_NET_BRIDGE 1

/* Define to 1 if you have the declaration of `NET_CIPSOV4_CACHE_BUCKET_SIZE',
   and to 0 if you don't. */
#define HAVE_DECL_NET_CIPSOV4_CACHE_BUCKET_SIZE 1

/* Define to 1 if you have the declaration of `NET_CIPSOV4_CACHE_ENABLE', and
   to 0 if you don't. */
#define HAVE_DECL_NET_CIPSOV4_CACHE_ENABLE 1

/* Define to 1 if you have the declaration of `NET_CIPSOV4_RBM_OPTFMT', and to
   0 if you don't. */
#define HAVE_DECL_NET_CIPSOV4_RBM_OPTFMT 1

/* Define to 1 if you have the declaration of `NET_CIPSOV4_RBM_STRICTVALID',
   and to 0 if you don't. */
#define HAVE_DECL_NET_CIPSOV4_RBM_STRICTVALID 1

/* Define to 1 if you have the declaration of `NET_CORE', and to 0 if you
   don't. */
#define HAVE_DECL_NET_CORE 1

/* Define to 1 if you have the declaration of `NET_CORE_AEVENT_ETIME', and to
   0 if you don't. */
#define HAVE_DECL_NET_CORE_AEVENT_ETIME 1

/* Define to 1 if you have the declaration of `NET_CORE_AEVENT_RSEQTH', and to
   0 if you don't. */
#define HAVE_DECL_NET_CORE_AEVENT_RSEQTH 1

/* Define to 1 if you have the declaration of `NET_CORE_BUDGET', and to 0 if
   you don't. */
#define HAVE_DECL_NET_CORE_BUDGET 1

/* Define to 1 if you have the declaration of `NET_CORE_DESTROY_DELAY', and to
   0 if you don't. */
#define HAVE_DECL_NET_CORE_DESTROY_DELAY 0

/* Define to 1 if you have the declaration of `NET_CORE_DEV_WEIGHT', and to 0
   if you don't. */
#define HAVE_DECL_NET_CORE_DEV_WEIGHT 1

/* Define to 1 if you have the declaration of `NET_CORE_DIVERT_VERSION', and
   to 0 if you don't. */
#define HAVE_DECL_NET_CORE_DIVERT_VERSION 1

/* Define to 1 if you have the declaration of `NET_CORE_FASTROUTE', and to 0
   if you don't. */
#define HAVE_DECL_NET_CORE_FASTROUTE 1

/* Define to 1 if you have the declaration of `NET_CORE_HOT_LIST_LENGTH', and
   to 0 if you don't. */
#define HAVE_DECL_NET_CORE_HOT_LIST_LENGTH 1

/* Define to 1 if you have the declaration of `NET_CORE_LO_CONG', and to 0 if
   you don't. */
#define HAVE_DECL_NET_CORE_LO_CONG 1

/* Define to 1 if you have the declaration of `NET_CORE_MAX_BACKLOG', and to 0
   if you don't. */
#define HAVE_DECL_NET_CORE_MAX_BACKLOG 1

/* Define to 1 if you have the declaration of `NET_CORE_MOD_CONG', and to 0 if
   you don't. */
#define HAVE_DECL_NET_CORE_MOD_CONG 1

/* Define to 1 if you have the declaration of `NET_CORE_MSG_BURST', and to 0
   if you don't. */
#define HAVE_DECL_NET_CORE_MSG_BURST 1

/* Define to 1 if you have the declaration of `NET_CORE_MSG_COST', and to 0 if
   you don't. */
#define HAVE_DECL_NET_CORE_MSG_COST 1

/* Define to 1 if you have the declaration of `NET_CORE_NO_CONG', and to 0 if
   you don't. */
#define HAVE_DECL_NET_CORE_NO_CONG 1

/* Define to 1 if you have the declaration of `NET_CORE_NO_CONG_THRESH', and
   to 0 if you don't. */
#define HAVE_DECL_NET_CORE_NO_CONG_THRESH 1

/* Define to 1 if you have the declaration of `NET_CORE_OPTMEM_MAX', and to 0
   if you don't. */
#define HAVE_DECL_NET_CORE_OPTMEM_MAX 1

/* Define to 1 if you have the declaration of `NET_CORE_RMEM_DEFAULT', and to
   0 if you don't. */
#define HAVE_DECL_NET_CORE_RMEM_DEFAULT 1

/* Define to 1 if you have the declaration of `NET_CORE_RMEM_MAX', and to 0 if
   you don't. */
#define HAVE_DECL_NET_CORE_RMEM_MAX 1

/* Define to 1 if you have the declaration of `NET_CORE_SOMAXCONN', and to 0
   if you don't. */
#define HAVE_DECL_NET_CORE_SOMAXCONN 1

/* Define to 1 if you have the declaration of `NET_CORE_WARNINGS', and to 0 if
   you don't. */
#define HAVE_DECL_NET_CORE_WARNINGS 1

/* Define to 1 if you have the declaration of `NET_CORE_WMEM_DEFAULT', and to
   0 if you don't. */
#define HAVE_DECL_NET_CORE_WMEM_DEFAULT 1

/* Define to 1 if you have the declaration of `NET_CORE_WMEM_MAX', and to 0 if
   you don't. */
#define HAVE_DECL_NET_CORE_WMEM_MAX 1

/* Define to 1 if you have the declaration of `NET_DCCP', and to 0 if you
   don't. */
#define HAVE_DECL_NET_DCCP 1

/* Define to 1 if you have the declaration of `NET_DECNET', and to 0 if you
   don't. */
#define HAVE_DECL_NET_DECNET 1

/* Define to 1 if you have the declaration of `NET_ECONET', and to 0 if you
   don't. */
#define HAVE_DECL_NET_ECONET 1

/* Define to 1 if you have the declaration of `NET_ETHER', and to 0 if you
   don't. */
#define HAVE_DECL_NET_ETHER 1

/* Define to 1 if you have the declaration of `NET_IPV4', and to 0 if you
   don't. */
#define HAVE_DECL_NET_IPV4 1

/* Define to 1 if you have the declaration of `NET_IPV4_ALWAYS_DEFRAG', and to
   0 if you don't. */
#define HAVE_DECL_NET_IPV4_ALWAYS_DEFRAG 1

/* Define to 1 if you have the declaration of `NET_IPV4_AUTOCONFIG', and to 0
   if you don't. */
#define HAVE_DECL_NET_IPV4_AUTOCONFIG 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF', and to 0 if you
   don't. */
#define HAVE_DECL_NET_IPV4_CONF 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_CONF_ACCEPT_REDIRECTS', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_ACCEPT_REDIRECTS 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_CONF_ACCEPT_SOURCE_ROUTE', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_ACCEPT_SOURCE_ROUTE 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_ARPFILTER', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_ARPFILTER 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_ARP_ACCEPT', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_ARP_ACCEPT 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_ARP_ANNOUNCE',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_ARP_ANNOUNCE 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_CONF_ARP_EVICT_NOCARRIER', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_ARP_EVICT_NOCARRIER 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_ARP_IGNORE', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_ARP_IGNORE 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_ARP_NOTIFY', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_ARP_NOTIFY 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_BOOTP_RELAY', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_BOOTP_RELAY 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_CONF_FORCE_IGMP_VERSION', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_FORCE_IGMP_VERSION 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_FORWARDING', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_FORWARDING 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_LOG_MARTIANS',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_LOG_MARTIANS 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_MC_FORWARDING',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_MC_FORWARDING 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_MEDIUM_ID', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_MEDIUM_ID 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_NOPOLICY', and to
   0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_NOPOLICY 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_NOXFRM', and to 0
   if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_NOXFRM 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_CONF_PROMOTE_SECONDARIES', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_PROMOTE_SECONDARIES 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_PROXY_ARP', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_PROXY_ARP 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_RP_FILTER', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_RP_FILTER 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_CONF_SECURE_REDIRECTS', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_SECURE_REDIRECTS 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_SEND_REDIRECTS',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_SEND_REDIRECTS 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_SHARED_MEDIA',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_CONF_SHARED_MEDIA 1

/* Define to 1 if you have the declaration of `NET_IPV4_CONF_TAG', and to 0 if
   you don't. */
#define HAVE_DECL_NET_IPV4_CONF_TAG 1

/* Define to 1 if you have the declaration of `NET_IPV4_DEFAULT_TTL', and to 0
   if you don't. */
#define HAVE_DECL_NET_IPV4_DEFAULT_TTL 1

/* Define to 1 if you have the declaration of `NET_IPV4_DYNADDR', and to 0 if
   you don't. */
#define HAVE_DECL_NET_IPV4_DYNADDR 1

/* Define to 1 if you have the declaration of `NET_IPV4_FIB_HASH', and to 0 if
   you don't. */
#define HAVE_DECL_NET_IPV4_FIB_HASH 1

/* Define to 1 if you have the declaration of `NET_IPV4_FORWARD', and to 0 if
   you don't. */
#define HAVE_DECL_NET_IPV4_FORWARD 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_ICMP_DESTUNREACH_RATE', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ICMP_DESTUNREACH_RATE 1

/* Define to 1 if you have the declaration of `NET_IPV4_ICMP_ECHOREPLY_RATE',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ICMP_ECHOREPLY_RATE 1

/* Define to 1 if you have the declaration of `NET_IPV4_ICMP_ECHO_IGNORE_ALL',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ICMP_ECHO_IGNORE_ALL 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_ICMP_ECHO_IGNORE_BROADCASTS', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ICMP_ECHO_IGNORE_BROADCASTS 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_ICMP_IGNORE_BOGUS_ERROR_RESPONSES', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ICMP_IGNORE_BOGUS_ERROR_RESPONSES 1

/* Define to 1 if you have the declaration of `NET_IPV4_ICMP_PARAMPROB_RATE',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ICMP_PARAMPROB_RATE 1

/* Define to 1 if you have the declaration of `NET_IPV4_ICMP_RATELIMIT', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ICMP_RATELIMIT 1

/* Define to 1 if you have the declaration of `NET_IPV4_ICMP_RATEMASK', and to
   0 if you don't. */
#define HAVE_DECL_NET_IPV4_ICMP_RATEMASK 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_ICMP_SOURCEQUENCH_RATE', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ICMP_SOURCEQUENCH_RATE 1

/* Define to 1 if you have the declaration of `NET_IPV4_ICMP_TIMEEXCEED_RATE',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ICMP_TIMEEXCEED_RATE 1

/* Define to 1 if you have the declaration of `NET_IPV4_IGMP_MAX_MEMBERSHIPS',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_IGMP_MAX_MEMBERSHIPS 1

/* Define to 1 if you have the declaration of `NET_IPV4_IGMP_MAX_MSF', and to
   0 if you don't. */
#define HAVE_DECL_NET_IPV4_IGMP_MAX_MSF 1

/* Define to 1 if you have the declaration of `NET_IPV4_INET_PEER_GC_MAXTIME',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_INET_PEER_GC_MAXTIME 1

/* Define to 1 if you have the declaration of `NET_IPV4_INET_PEER_GC_MINTIME',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_INET_PEER_GC_MINTIME 1

/* Define to 1 if you have the declaration of `NET_IPV4_INET_PEER_MAXTTL', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_INET_PEER_MAXTTL 1

/* Define to 1 if you have the declaration of `NET_IPV4_INET_PEER_MINTTL', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_INET_PEER_MINTTL 1

/* Define to 1 if you have the declaration of `NET_IPV4_INET_PEER_THRESHOLD',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_INET_PEER_THRESHOLD 1

/* Define to 1 if you have the declaration of `NET_IPV4_IPFRAG_HIGH_THRESH',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_IPFRAG_HIGH_THRESH 1

/* Define to 1 if you have the declaration of `NET_IPV4_IPFRAG_LOW_THRESH',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_IPFRAG_LOW_THRESH 1

/* Define to 1 if you have the declaration of `NET_IPV4_IPFRAG_MAX_DIST', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_IPFRAG_MAX_DIST 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_IPFRAG_SECRET_INTERVAL', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_IPFRAG_SECRET_INTERVAL 1

/* Define to 1 if you have the declaration of `NET_IPV4_IPFRAG_TIME', and to 0
   if you don't. */
#define HAVE_DECL_NET_IPV4_IPFRAG_TIME 1

/* Define to 1 if you have the declaration of `NET_IPV4_IP_MASQ_DEBUG', and to
   0 if you don't. */
#define HAVE_DECL_NET_IPV4_IP_MASQ_DEBUG 1

/* Define to 1 if you have the declaration of `NET_IPV4_LOCAL_PORT_RANGE', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_LOCAL_PORT_RANGE 1

/* Define to 1 if you have the declaration of `NET_IPV4_NEIGH', and to 0 if
   you don't. */
#define HAVE_DECL_NET_IPV4_NEIGH 1

/* Define to 1 if you have the declaration of `NET_IPV4_NETFILTER', and to 0
   if you don't. */
#define HAVE_DECL_NET_IPV4_NETFILTER 1

/* Define to 1 if you have the declaration of `NET_IPV4_NONLOCAL_BIND', and to
   0 if you don't. */
#define HAVE_DECL_NET_IPV4_NONLOCAL_BIND 1

/* Define to 1 if you have the declaration of `NET_IPV4_NO_PMTU_DISC', and to
   0 if you don't. */
#define HAVE_DECL_NET_IPV4_NO_PMTU_DISC 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE', and to 0 if
   you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_ERROR_BURST',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_ERROR_BURST 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_ERROR_COST', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_ERROR_COST 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_FLUSH', and to 0
   if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_FLUSH 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_GC_ELASTICITY',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_GC_ELASTICITY 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_GC_INTERVAL',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_GC_INTERVAL 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_ROUTE_GC_MIN_INTERVAL', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_GC_MIN_INTERVAL 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_GC_THRESH', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_GC_THRESH 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_GC_TIMEOUT', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_GC_TIMEOUT 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_MAX_DELAY', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_MAX_DELAY 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_MAX_SIZE', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_MAX_SIZE 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_MIN_ADVMSS', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_MIN_ADVMSS 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_MIN_DELAY', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_MIN_DELAY 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_MIN_PMTU', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_MIN_PMTU 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_MTU_EXPIRES',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_MTU_EXPIRES 1

/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_REDIRECT_LOAD',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_REDIRECT_LOAD 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_ROUTE_REDIRECT_NUMBER', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_REDIRECT_NUMBER 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_ROUTE_REDIRECT_SILENCE', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_REDIRECT_SILENCE 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_ROUTE_SECRET_INTERVAL', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_ROUTE_SECRET_INTERVAL 1

/* Define to 1 if you have the declaration of `NET_IPV4_TCP_FIN_TIMEOUT', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_TCP_FIN_TIMEOUT 1

/* Define to 1 if you have the declaration of `NET_IPV4_TCP_KEEPALIVE_INTVL',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_TCP_KEEPALIVE_INTVL 1

/* Define to 1 if you have the declaration of `NET_IPV4_TCP_KEEPALIVE_PROBES',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_TCP_KEEPALIVE_PROBES 1

/* Define to 1 if you have the declaration of `NET_IPV4_TCP_KEEPALIVE_TIME',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_TCP_KEEPALIVE_TIME 1

/* Define to 1 if you have the declaration of `NET_IPV4_TCP_MAX_KA_PROBES',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_TCP_MAX_KA_PROBES 1

/* Define to 1 if you have the declaration of `NET_IPV4_TCP_RETRANS_COLLAPSE',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_TCP_RETRANS_COLLAPSE 1

/* Define to 1 if you have the declaration of `NET_IPV4_TCP_RETRIES1', and to
   0 if you don't. */
#define HAVE_DECL_NET_IPV4_TCP_RETRIES1 1

/* Define to 1 if you have the declaration of `NET_IPV4_TCP_RETRIES2', and to
   0 if you don't. */
#define HAVE_DECL_NET_IPV4_TCP_RETRIES2 1

/* Define to 1 if you have the declaration of `NET_IPV4_TCP_SACK', and to 0 if
   you don't. */
#define HAVE_DECL_NET_IPV4_TCP_SACK 1

/* Define to 1 if you have the declaration of `NET_IPV4_TCP_SYN_RETRIES', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_TCP_SYN_RETRIES 1

/* Define to 1 if you have the declaration of `NET_IPV4_TCP_TIMESTAMPS', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_TCP_TIMESTAMPS 1

/* Define to 1 if you have the declaration of `NET_IPV4_TCP_WINDOW_SCALING',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_TCP_WINDOW_SCALING 1

/* Define to 1 if you have the declaration of
   `NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS 1

/* Define to 1 if you have the declaration of `NET_IPV6', and to 0 if you
   don't. */
#define HAVE_DECL_NET_IPV6 1

/* Define to 1 if you have the declaration of `NET_IPV6_BINDV6ONLY', and to 0
   if you don't. */
#define HAVE_DECL_NET_IPV6_BINDV6ONLY 1

/* Define to 1 if you have the declaration of `NET_IPV6_CONF', and to 0 if you
   don't. */
#define HAVE_DECL_NET_IPV6_CONF 1

/* Define to 1 if you have the declaration of `NET_IPV6_ICMP', and to 0 if you
   don't. */
#define HAVE_DECL_NET_IPV6_ICMP 1

/* Define to 1 if you have the declaration of `NET_IPV6_IP6FRAG_HIGH_THRESH',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV6_IP6FRAG_HIGH_THRESH 1

/* Define to 1 if you have the declaration of `NET_IPV6_IP6FRAG_LOW_THRESH',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV6_IP6FRAG_LOW_THRESH 1

/* Define to 1 if you have the declaration of
   `NET_IPV6_IP6FRAG_SECRET_INTERVAL', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV6_IP6FRAG_SECRET_INTERVAL 1

/* Define to 1 if you have the declaration of `NET_IPV6_IP6FRAG_TIME', and to
   0 if you don't. */
#define HAVE_DECL_NET_IPV6_IP6FRAG_TIME 1

/* Define to 1 if you have the declaration of `NET_IPV6_MLD_MAX_MSF', and to 0
   if you don't. */
#define HAVE_DECL_NET_IPV6_MLD_MAX_MSF 1

/* Define to 1 if you have the declaration of `NET_IPV6_NEIGH', and to 0 if
   you don't. */
#define HAVE_DECL_NET_IPV6_NEIGH 1

/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE', and to 0 if
   you don't. */
#define HAVE_DECL_NET_IPV6_ROUTE 1

/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_FLUSH', and to 0
   if you don't. */
#define HAVE_DECL_NET_IPV6_ROUTE_FLUSH 1

/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_GC_ELASTICITY',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV6_ROUTE_GC_ELASTICITY 1

/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_GC_INTERVAL',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV6_ROUTE_GC_INTERVAL 1

/* Define to 1 if you have the declaration of
   `NET_IPV6_ROUTE_GC_MIN_INTERVAL', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV6_ROUTE_GC_MIN_INTERVAL 1

/* Define to 1 if you have the declaration of
   `NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS', and to 0 if you don't. */
#define HAVE_DECL_NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS 1

/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_GC_THRESH', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV6_ROUTE_GC_THRESH 1

/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_GC_TIMEOUT', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV6_ROUTE_GC_TIMEOUT 1

/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_MAX_SIZE', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV6_ROUTE_MAX_SIZE 1

/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_MIN_ADVMSS', and
   to 0 if you don't. */
#define HAVE_DECL_NET_IPV6_ROUTE_MIN_ADVMSS 1

/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_MTU_EXPIRES',
   and to 0 if you don't. */
#define HAVE_DECL_NET_IPV6_ROUTE_MTU_EXPIRES 1

/* Define to 1 if you have the declaration of `NET_IPX', and to 0 if you
   don't. */
#define HAVE_DECL_NET_IPX 1

/* Define to 1 if you have the declaration of `NET_IRDA', and to 0 if you
   don't. */
#define HAVE_DECL_NET_IRDA 1

/* Define to 1 if you have the declaration of `NET_LLC', and to 0 if you
   don't. */
#define HAVE_DECL_NET_LLC 1

/* Define to 1 if you have the declaration of `NET_NETFILTER', and to 0 if you
   don't. */
#define HAVE_DECL_NET_NETFILTER 1

/* Define to 1 if you have the declaration of `NET_NETROM', and to 0 if you
   don't. */
#define HAVE_DECL_NET_NETROM 1

/* Define to 1 if you have the declaration of `NET_ROSE', and to 0 if you
   don't. */
#define HAVE_DECL_NET_ROSE 1

/* Define to 1 if you have the declaration of `NET_SCTP', and to 0 if you
   don't. */
#define HAVE_DECL_NET_SCTP 1

/* Define to 1 if you have the declaration of `NET_TCP_ABC', and to 0 if you
   don't. */
#define HAVE_DECL_NET_TCP_ABC 1

/* Define to 1 if you have the declaration of `NET_TCP_ABORT_ON_OVERFLOW', and
   to 0 if you don't. */
#define HAVE_DECL_NET_TCP_ABORT_ON_OVERFLOW 1

/* Define to 1 if you have the declaration of `NET_TCP_ADV_WIN_SCALE', and to
   0 if you don't. */
#define HAVE_DECL_NET_TCP_ADV_WIN_SCALE 1

/* Define to 1 if you have the declaration of `NET_TCP_ALLOWED_CONG_CONTROL',
   and to 0 if you don't. */
#define HAVE_DECL_NET_TCP_ALLOWED_CONG_CONTROL 1

/* Define to 1 if you have the declaration of `NET_TCP_APP_WIN', and to 0 if
   you don't. */
#define HAVE_DECL_NET_TCP_APP_WIN 1

/* Define to 1 if you have the declaration of `NET_TCP_AVAIL_CONG_CONTROL',
   and to 0 if you don't. */
#define HAVE_DECL_NET_TCP_AVAIL_CONG_CONTROL 1

/* Define to 1 if you have the declaration of `NET_TCP_BASE_MSS', and to 0 if
   you don't. */
#define HAVE_DECL_NET_TCP_BASE_MSS 1

/* Define to 1 if you have the declaration of `NET_TCP_BIC', and to 0 if you
   don't. */
#define HAVE_DECL_NET_TCP_BIC 0

/* Define to 1 if you have the declaration of `NET_TCP_BIC_BETA', and to 0 if
   you don't. */
#define HAVE_DECL_NET_TCP_BIC_BETA 1

/* Define to 1 if you have the declaration of `NET_TCP_BIC_FAST_CONVERGENCE',
   and to 0 if you don't. */
#define HAVE_DECL_NET_TCP_BIC_FAST_CONVERGENCE 0

/* Define to 1 if you have the declaration of `NET_TCP_BIC_LOW_WINDOW', and to
   0 if you don't. */
#define HAVE_DECL_NET_TCP_BIC_LOW_WINDOW 0

/* Define to 1 if you have the declaration of `NET_TCP_CONG_CONTROL', and to 0
   if you don't. */
#define HAVE_DECL_NET_TCP_CONG_CONTROL 1

/* Define to 1 if you have the declaration of `NET_TCP_DEFAULT_WIN_SCALE', and
   to 0 if you don't. */
#define HAVE_DECL_NET_TCP_DEFAULT_WIN_SCALE 1

/* Define to 1 if you have the declaration of `NET_TCP_DMA_COPYBREAK', and to
   0 if you don't. */
#define HAVE_DECL_NET_TCP_DMA_COPYBREAK 1

/* Define to 1 if you have the declaration of `NET_TCP_DSACK', and to 0 if you
   don't. */
#define HAVE_DECL_NET_TCP_DSACK 1

/* Define to 1 if you have the declaration of `NET_TCP_ECN', and to 0 if you
   don't. */
#define HAVE_DECL_NET_TCP_ECN 1

/* Define to 1 if you have the declaration of `NET_TCP_FACK', and to 0 if you
   don't. */
#define HAVE_DECL_NET_TCP_FACK 1

/* Define to 1 if you have the declaration of `NET_TCP_FRTO', and to 0 if you
   don't. */
#define HAVE_DECL_NET_TCP_FRTO 1

/* Define to 1 if you have the declaration of `NET_TCP_FRTO_RESPONSE', and to
   0 if you don't. */
#define HAVE_DECL_NET_TCP_FRTO_RESPONSE 1

/* Define to 1 if you have the declaration of `NET_TCP_LOW_LATENCY', and to 0
   if you don't. */
#define HAVE_DECL_NET_TCP_LOW_LATENCY 1

/* Define to 1 if you have the declaration of `NET_TCP_MAX_ORPHANS', and to 0
   if you don't. */
#define HAVE_DECL_NET_TCP_MAX_ORPHANS 1

/* Define to 1 if you have the declaration of `NET_TCP_MAX_SSTHRESH', and to 0
   if you don't. */
#define HAVE_DECL_NET_TCP_MAX_SSTHRESH 1

/* Define to 1 if you have the declaration of `NET_TCP_MAX_SYN_BACKLOG', and
   to 0 if you don't. */
#define HAVE_DECL_NET_TCP_MAX_SYN_BACKLOG 1

/* Define to 1 if you have the declaration of `NET_TCP_MAX_TW_BUCKETS', and to
   0 if you don't. */
#define HAVE_DECL_NET_TCP_MAX_TW_BUCKETS 1

/* Define to 1 if you have the declaration of `NET_TCP_MEM', and to 0 if you
   don't. */
#define HAVE_DECL_NET_TCP_MEM 1

/* Define to 1 if you have the declaration of `NET_TCP_MODERATE_RCVBUF', and
   to 0 if you don't. */
#define HAVE_DECL_NET_TCP_MODERATE_RCVBUF 1

/* Define to 1 if you have the declaration of `NET_TCP_MTU_PROBING', and to 0
   if you don't. */
#define HAVE_DECL_NET_TCP_MTU_PROBING 1

/* Define to 1 if you have the declaration of `NET_TCP_NO_METRICS_SAVE', and
   to 0 if you don't. */
#define HAVE_DECL_NET_TCP_NO_METRICS_SAVE 1

/* Define to 1 if you have the declaration of `NET_TCP_ORPHAN_RETRIES', and to
   0 if you don't. */
#define HAVE_DECL_NET_TCP_ORPHAN_RETRIES 1

/* Define to 1 if you have the declaration of `NET_TCP_REORDERING', and to 0
   if you don't. */
#define HAVE_DECL_NET_TCP_REORDERING 1

/* Define to 1 if you have the declaration of `NET_TCP_RFC1337', and to 0 if
   you don't. */
#define HAVE_DECL_NET_TCP_RFC1337 1

/* Define to 1 if you have the declaration of `NET_TCP_RMEM', and to 0 if you
   don't. */
#define HAVE_DECL_NET_TCP_RMEM 1

/* Define to 1 if you have the declaration of `NET_TCP_SLOW_START_AFTER_IDLE',
   and to 0 if you don't. */
#define HAVE_DECL_NET_TCP_SLOW_START_AFTER_IDLE 1

/* Define to 1 if you have the declaration of `NET_TCP_STDURG', and to 0 if
   you don't. */
#define HAVE_DECL_NET_TCP_STDURG 1

/* Define to 1 if you have the declaration of `NET_TCP_SYNACK_RETRIES', and to
   0 if you don't. */
#define HAVE_DECL_NET_TCP_SYNACK_RETRIES 1

/* Define to 1 if you have the declaration of `NET_TCP_SYNCOOKIES', and to 0
   if you don't. */
#define HAVE_DECL_NET_TCP_SYNCOOKIES 1

/* Define to 1 if you have the declaration of `NET_TCP_SYN_TAILDROP', and to 0
   if you don't. */
#define HAVE_DECL_NET_TCP_SYN_TAILDROP 1

/* Define to 1 if you have the declaration of `NET_TCP_TSO_WIN_DIVISOR', and
   to 0 if you don't. */
#define HAVE_DECL_NET_TCP_TSO_WIN_DIVISOR 1

/* Define to 1 if you have the declaration of `NET_TCP_TW_RECYCLE', and to 0
   if you don't. */
#define HAVE_DECL_NET_TCP_TW_RECYCLE 1

/* Define to 1 if you have the declaration of `NET_TCP_TW_REUSE', and to 0 if
   you don't. */
#define HAVE_DECL_NET_TCP_TW_REUSE 1

/* Define to 1 if you have the declaration of `NET_TCP_VEGAS', and to 0 if you
   don't. */
#define HAVE_DECL_NET_TCP_VEGAS 0

/* Define to 1 if you have the declaration of `NET_TCP_VEGAS_ALPHA', and to 0
   if you don't. */
#define HAVE_DECL_NET_TCP_VEGAS_ALPHA 0

/* Define to 1 if you have the declaration of `NET_TCP_VEGAS_BETA', and to 0
   if you don't. */
#define HAVE_DECL_NET_TCP_VEGAS_BETA 0

/* Define to 1 if you have the declaration of `NET_TCP_VEGAS_GAMMA', and to 0
   if you don't. */
#define HAVE_DECL_NET_TCP_VEGAS_GAMMA 0

/* Define to 1 if you have the declaration of `NET_TCP_WESTWOOD', and to 0 if
   you don't. */
#define HAVE_DECL_NET_TCP_WESTWOOD 0

/* Define to 1 if you have the declaration of `NET_TCP_WMEM', and to 0 if you
   don't. */
#define HAVE_DECL_NET_TCP_WMEM 1

/* Define to 1 if you have the declaration of `NET_TR', and to 0 if you don't.
   */
#define HAVE_DECL_NET_TR 1

/* Define to 1 if you have the declaration of `NET_UNIX', and to 0 if you
   don't. */
#define HAVE_DECL_NET_UNIX 1

/* Define to 1 if you have the declaration of `NET_UNIX_DELETE_DELAY', and to
   0 if you don't. */
#define HAVE_DECL_NET_UNIX_DELETE_DELAY 1

/* Define to 1 if you have the declaration of `NET_UNIX_DESTROY_DELAY', and to
   0 if you don't. */
#define HAVE_DECL_NET_UNIX_DESTROY_DELAY 1

/* Define to 1 if you have the declaration of `NET_UNIX_MAX_DGRAM_QLEN', and
   to 0 if you don't. */
#define HAVE_DECL_NET_UNIX_MAX_DGRAM_QLEN 1

/* Define to 1 if you have the declaration of `NET_X25', and to 0 if you
   don't. */
#define HAVE_DECL_NET_X25 1

/* Define to 1 if you have the declaration of `NFEA_ACTIVITY_NOTIFY', and to 0
   if you don't. */
#define HAVE_DECL_NFEA_ACTIVITY_NOTIFY 0

/* Define to 1 if you have the declaration of `NFEA_DONT_REFRESH', and to 0 if
   you don't. */
#define HAVE_DECL_NFEA_DONT_REFRESH 0

/* Define to 1 if you have the declaration of `NFEA_UNSPEC', and to 0 if you
   don't. */
#define HAVE_DECL_NFEA_UNSPEC 0

/* Define to 1 if you have the declaration of `PTRACE_PEEKUSER', and to 0 if
   you don't. */
#define HAVE_DECL_PTRACE_PEEKUSER 1

/* Define to 1 if you have the declaration of `PTRACE_POKEUSER', and to 0 if
   you don't. */
#define HAVE_DECL_PTRACE_POKEUSER 1

/* Define to 1 if you have the declaration of `P_ALL', and to 0 if you don't.
   */
#define HAVE_DECL_P_ALL 1

/* Define to 1 if you have the declaration of `P_PGID', and to 0 if you don't.
   */
#define HAVE_DECL_P_PGID 1

/* Define to 1 if you have the declaration of `P_PID', and to 0 if you don't.
   */
#define HAVE_DECL_P_PID 1

/* Define to 1 if you have the declaration of `P_PIDFD', and to 0 if you
   don't. */
#define HAVE_DECL_P_PIDFD 1

/* Define to 1 if you have the declaration of `sys_errlist', and to 0 if you
   don't. */
#define HAVE_DECL_SYS_ERRLIST 0

/* Define to 1 if you have the declaration of `TCA_ACT_COOKIE', and to 0 if
   you don't. */
#define HAVE_DECL_TCA_ACT_COOKIE 1

/* Define to 1 if you have the declaration of `TCA_ACT_FLAGS', and to 0 if you
   don't. */
#define HAVE_DECL_TCA_ACT_FLAGS 1

/* Define to 1 if you have the declaration of `TCA_ACT_HW_STATS', and to 0 if
   you don't. */
#define HAVE_DECL_TCA_ACT_HW_STATS 1

/* Define to 1 if you have the declaration of `TCA_ACT_INDEX', and to 0 if you
   don't. */
#define HAVE_DECL_TCA_ACT_INDEX 1

/* Define to 1 if you have the declaration of `TCA_ACT_IN_HW_COUNT', and to 0
   if you don't. */
#define HAVE_DECL_TCA_ACT_IN_HW_COUNT 1

/* Define to 1 if you have the declaration of `TCA_ACT_KIND', and to 0 if you
   don't. */
#define HAVE_DECL_TCA_ACT_KIND 1

/* Define to 1 if you have the declaration of `TCA_ACT_OPTIONS', and to 0 if
   you don't. */
#define HAVE_DECL_TCA_ACT_OPTIONS 1

/* Define to 1 if you have the declaration of `TCA_ACT_PAD', and to 0 if you
   don't. */
#define HAVE_DECL_TCA_ACT_PAD 1

/* Define to 1 if you have the declaration of `TCA_ACT_STATS', and to 0 if you
   don't. */
#define HAVE_DECL_TCA_ACT_STATS 1

/* Define to 1 if you have the declaration of `TCA_ACT_UNSPEC', and to 0 if
   you don't. */
#define HAVE_DECL_TCA_ACT_UNSPEC 1

/* Define to 1 if you have the declaration of `TCA_ACT_USED_HW_STATS', and to
   0 if you don't. */
#define HAVE_DECL_TCA_ACT_USED_HW_STATS 1

/* Define to 1 if you have the declaration of `VM_BLOCK_DUMP', and to 0 if you
   don't. */
#define HAVE_DECL_VM_BLOCK_DUMP 1

/* Define to 1 if you have the declaration of `VM_CMM_PAGES', and to 0 if you
   don't. */
#define HAVE_DECL_VM_CMM_PAGES 0

/* Define to 1 if you have the declaration of `VM_CMM_TIMED_PAGES', and to 0
   if you don't. */
#define HAVE_DECL_VM_CMM_TIMED_PAGES 0

/* Define to 1 if you have the declaration of `VM_CMM_TIMEOUT', and to 0 if
   you don't. */
#define HAVE_DECL_VM_CMM_TIMEOUT 0

/* Define to 1 if you have the declaration of `VM_DIRTY_BACKGROUND', and to 0
   if you don't. */
#define HAVE_DECL_VM_DIRTY_BACKGROUND 1

/* Define to 1 if you have the declaration of `VM_DIRTY_EXPIRE_CS', and to 0
   if you don't. */
#define HAVE_DECL_VM_DIRTY_EXPIRE_CS 1

/* Define to 1 if you have the declaration of `VM_DIRTY_RATIO', and to 0 if
   you don't. */
#define HAVE_DECL_VM_DIRTY_RATIO 1

/* Define to 1 if you have the declaration of `VM_DIRTY_WB_CS', and to 0 if
   you don't. */
#define HAVE_DECL_VM_DIRTY_WB_CS 1

/* Define to 1 if you have the declaration of `VM_DROP_PAGECACHE', and to 0 if
   you don't. */
#define HAVE_DECL_VM_DROP_PAGECACHE 1

/* Define to 1 if you have the declaration of `VM_HUGETLB_GROUP', and to 0 if
   you don't. */
#define HAVE_DECL_VM_HUGETLB_GROUP 1

/* Define to 1 if you have the declaration of `VM_HUGETLB_PAGES', and to 0 if
   you don't. */
#define HAVE_DECL_VM_HUGETLB_PAGES 1

/* Define to 1 if you have the declaration of `VM_LAPTOP_MODE', and to 0 if
   you don't. */
#define HAVE_DECL_VM_LAPTOP_MODE 1

/* Define to 1 if you have the declaration of `VM_LEGACY_VA_LAYOUT', and to 0
   if you don't. */
#define HAVE_DECL_VM_LEGACY_VA_LAYOUT 1

/* Define to 1 if you have the declaration of `VM_LOWMEM_RESERVE_RATIO', and
   to 0 if you don't. */
#define HAVE_DECL_VM_LOWMEM_RESERVE_RATIO 1

/* Define to 1 if you have the declaration of `VM_MAX_MAP_COUNT', and to 0 if
   you don't. */
#define HAVE_DECL_VM_MAX_MAP_COUNT 1

/* Define to 1 if you have the declaration of `VM_MIN_FREE_KBYTES', and to 0
   if you don't. */
#define HAVE_DECL_VM_MIN_FREE_KBYTES 1

/* Define to 1 if you have the declaration of `VM_MIN_SLAB', and to 0 if you
   don't. */
#define HAVE_DECL_VM_MIN_SLAB 1

/* Define to 1 if you have the declaration of `VM_MIN_UNMAPPED', and to 0 if
   you don't. */
#define HAVE_DECL_VM_MIN_UNMAPPED 1

/* Define to 1 if you have the declaration of `VM_NR_PDFLUSH_THREADS', and to
   0 if you don't. */
#define HAVE_DECL_VM_NR_PDFLUSH_THREADS 1

/* Define to 1 if you have the declaration of `VM_OVERCOMMIT_MEMORY', and to 0
   if you don't. */
#define HAVE_DECL_VM_OVERCOMMIT_MEMORY 1

/* Define to 1 if you have the declaration of `VM_OVERCOMMIT_RATIO', and to 0
   if you don't. */
#define HAVE_DECL_VM_OVERCOMMIT_RATIO 1

/* Define to 1 if you have the declaration of `VM_PAGEBUF', and to 0 if you
   don't. */
#define HAVE_DECL_VM_PAGEBUF 1

/* Define to 1 if you have the declaration of `VM_PAGE_CLUSTER', and to 0 if
   you don't. */
#define HAVE_DECL_VM_PAGE_CLUSTER 1

/* Define to 1 if you have the declaration of `VM_PANIC_ON_OOM', and to 0 if
   you don't. */
#define HAVE_DECL_VM_PANIC_ON_OOM 1

/* Define to 1 if you have the declaration of `VM_PERCPU_PAGELIST_FRACTION',
   and to 0 if you don't. */
#define HAVE_DECL_VM_PERCPU_PAGELIST_FRACTION 1

/* Define to 1 if you have the declaration of `VM_SWAPPINESS', and to 0 if you
   don't. */
#define HAVE_DECL_VM_SWAPPINESS 1

/* Define to 1 if you have the declaration of `VM_SWAP_TOKEN_TIMEOUT', and to
   0 if you don't. */
#define HAVE_DECL_VM_SWAP_TOKEN_TIMEOUT 1

/* Define to 1 if you have the declaration of `VM_UNUSED1', and to 0 if you
   don't. */
#define HAVE_DECL_VM_UNUSED1 1

/* Define to 1 if you have the declaration of `VM_UNUSED2', and to 0 if you
   don't. */
#define HAVE_DECL_VM_UNUSED2 1

/* Define to 1 if you have the declaration of `VM_UNUSED3', and to 0 if you
   don't. */
#define HAVE_DECL_VM_UNUSED3 1

/* Define to 1 if you have the declaration of `VM_UNUSED4', and to 0 if you
   don't. */
#define HAVE_DECL_VM_UNUSED4 1

/* Define to 1 if you have the declaration of `VM_UNUSED5', and to 0 if you
   don't. */
#define HAVE_DECL_VM_UNUSED5 1

/* Define to 1 if you have the declaration of `VM_UNUSED7', and to 0 if you
   don't. */
#define HAVE_DECL_VM_UNUSED7 1

/* Define to 1 if you have the declaration of `VM_UNUSED8', and to 0 if you
   don't. */
#define HAVE_DECL_VM_UNUSED8 1

/* Define to 1 if you have the declaration of `VM_UNUSED9', and to 0 if you
   don't. */
#define HAVE_DECL_VM_UNUSED9 1

/* Define to 1 if you have the declaration of `VM_VDSO_ENABLED', and to 0 if
   you don't. */
#define HAVE_DECL_VM_VDSO_ENABLED 1

/* Define to 1 if you have the declaration of `VM_VFS_CACHE_PRESSURE', and to
   0 if you don't. */
#define HAVE_DECL_VM_VFS_CACHE_PRESSURE 1

/* Define to 1 if you have the declaration of `VM_ZONE_RECLAIM_MODE', and to 0
   if you don't. */
#define HAVE_DECL_VM_ZONE_RECLAIM_MODE 1

/* Define to 1 if you have the declaration of `XFRM_MSG_ACQUIRE', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_ACQUIRE 1

/* Define to 1 if you have the declaration of `XFRM_MSG_ALLOCSPI', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_ALLOCSPI 1

/* Define to 1 if you have the declaration of `XFRM_MSG_DELPOLICY', and to 0
   if you don't. */
#define HAVE_DECL_XFRM_MSG_DELPOLICY 1

/* Define to 1 if you have the declaration of `XFRM_MSG_DELSA', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_DELSA 1

/* Define to 1 if you have the declaration of `XFRM_MSG_EXPIRE', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_EXPIRE 1

/* Define to 1 if you have the declaration of `XFRM_MSG_FLUSHPOLICY', and to 0
   if you don't. */
#define HAVE_DECL_XFRM_MSG_FLUSHPOLICY 1

/* Define to 1 if you have the declaration of `XFRM_MSG_FLUSHSA', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_FLUSHSA 1

/* Define to 1 if you have the declaration of `XFRM_MSG_GETAE', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_GETAE 1

/* Define to 1 if you have the declaration of `XFRM_MSG_GETDEFAULT', and to 0
   if you don't. */
#define HAVE_DECL_XFRM_MSG_GETDEFAULT 1

/* Define to 1 if you have the declaration of `XFRM_MSG_GETPOLICY', and to 0
   if you don't. */
#define HAVE_DECL_XFRM_MSG_GETPOLICY 1

/* Define to 1 if you have the declaration of `XFRM_MSG_GETSA', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_GETSA 1

/* Define to 1 if you have the declaration of `XFRM_MSG_GETSADINFO', and to 0
   if you don't. */
#define HAVE_DECL_XFRM_MSG_GETSADINFO 1

/* Define to 1 if you have the declaration of `XFRM_MSG_GETSPDINFO', and to 0
   if you don't. */
#define HAVE_DECL_XFRM_MSG_GETSPDINFO 1

/* Define to 1 if you have the declaration of `XFRM_MSG_MAPPING', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_MAPPING 1

/* Define to 1 if you have the declaration of `XFRM_MSG_MIGRATE', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_MIGRATE 1

/* Define to 1 if you have the declaration of `XFRM_MSG_NEWAE', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_NEWAE 1

/* Define to 1 if you have the declaration of `XFRM_MSG_NEWPOLICY', and to 0
   if you don't. */
#define HAVE_DECL_XFRM_MSG_NEWPOLICY 1

/* Define to 1 if you have the declaration of `XFRM_MSG_NEWSA', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_NEWSA 1

/* Define to 1 if you have the declaration of `XFRM_MSG_NEWSADINFO', and to 0
   if you don't. */
#define HAVE_DECL_XFRM_MSG_NEWSADINFO 1

/* Define to 1 if you have the declaration of `XFRM_MSG_NEWSPDINFO', and to 0
   if you don't. */
#define HAVE_DECL_XFRM_MSG_NEWSPDINFO 1

/* Define to 1 if you have the declaration of `XFRM_MSG_POLEXPIRE', and to 0
   if you don't. */
#define HAVE_DECL_XFRM_MSG_POLEXPIRE 1

/* Define to 1 if you have the declaration of `XFRM_MSG_REPORT', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_REPORT 1

/* Define to 1 if you have the declaration of `XFRM_MSG_SETDEFAULT', and to 0
   if you don't. */
#define HAVE_DECL_XFRM_MSG_SETDEFAULT 1

/* Define to 1 if you have the declaration of `XFRM_MSG_UPDPOLICY', and to 0
   if you don't. */
#define HAVE_DECL_XFRM_MSG_UPDPOLICY 1

/* Define to 1 if you have the declaration of `XFRM_MSG_UPDSA', and to 0 if
   you don't. */
#define HAVE_DECL_XFRM_MSG_UPDSA 1

/* Define to 1 if you have the <demangle.h> header file. */
/* #undef HAVE_DEMANGLE_H */

/* Define to 1 if the system provides dladdr */
#define HAVE_DLADDR 1

/* Define to 1 if you have the <elfutils/libdwfl.h> header file. */
/* #undef HAVE_ELFUTILS_LIBDWFL_H */

/* Define to 1 if you have the <elf.h> header file. */
#define HAVE_ELF_H 1

/* Define to 1 if you have the `fallocate' function. */
#define HAVE_FALLOCATE 1

/* Define to 1 if you have the `fanotify_mark' function. */
#define HAVE_FANOTIFY_MARK 1

/* Define to 1 if you have the `fcntl64' function. */
#define HAVE_FCNTL64 1

/* Define to 1 if you have the `fopen64' function. */
#define HAVE_FOPEN64 1

/* Define to 1 if you have the `fork' function. */
#define HAVE_FORK 1

/* Define to 1 if you have the `fputs_unlocked' function. */
#define HAVE_FPUTS_UNLOCKED 1

/* Define to 1 if you have the `fstatat' function. */
#define HAVE_FSTATAT 1

/* Define to 1 if you have the `ftruncate' function. */
#define HAVE_FTRUNCATE 1

/* Define to 1 if you have the `futimens' function. */
#define HAVE_FUTIMENS 1

/* Define to 1 if you have the <gcov.h> header file. */
/* #undef HAVE_GCOV_H */

/* Define to 1 if you have the <gnu/stubs-32.h> header file. */
/* #undef HAVE_GNU_STUBS_32_H */

/* Define to 1 if you have the <gnu/stubs-x32.h> header file. */
/* #undef HAVE_GNU_STUBS_X32_H */

/* Define to 1 if you have the <iconv.h> header file. */
#define HAVE_ICONV_H 1

/* Define to 1 if you have the `iconv_open' function. */
#define HAVE_ICONV_OPEN 1

/* Define to 1 if you have the `if_indextoname' function. */
#define HAVE_IF_INDEXTONAME 1

/* Define to 1 if you have the <inttypes.h> header file. */
#define HAVE_INTTYPES_H 1

/* Define to 1 if you have the <libiberty/demangle.h> header file. */
/* #undef HAVE_LIBIBERTY_DEMANGLE_H */

/* Define to 1 if you have the <libunwind-ptrace.h> header file. */
/* #undef HAVE_LIBUNWIND_PTRACE_H */

/* Define to 1 if you have the <linux/bpf.h> header file. */
#define HAVE_LINUX_BPF_H 1

/* Define to 1 if you have the <linux/if_alg.h> header file. */
#define HAVE_LINUX_IF_ALG_H 1

/* Define to 1 if you have the <linux/if_xdp.h> header file. */
#define HAVE_LINUX_IF_XDP_H 1

/* Define to 1 if you have the <linux/ipc.h> header file. */
#define HAVE_LINUX_IPC_H 1

/* Define to 1 if you have the <linux/ipx.h> header file. */
/* #undef HAVE_LINUX_IPX_H */

/* Define to 1 if you have the <linux/kvm.h> header file. */
/* #undef HAVE_LINUX_KVM_H */

/* Define to 1 if you have the <linux/netfilter_arp/arp_tables.h> header file.
   */
#define HAVE_LINUX_NETFILTER_ARP_ARP_TABLES_H 1

/* Define to 1 if you have the <linux/netfilter_bridge/ebtables.h> header
   file. */
#define HAVE_LINUX_NETFILTER_BRIDGE_EBTABLES_H 1

/* Define to 1 if you have the <linux/netfilter_ipv4/ip_tables.h> header file.
   */
#define HAVE_LINUX_NETFILTER_IPV4_IP_TABLES_H 1

/* Define to 1 if you have the <linux/netfilter_ipv6/ip6_tables.h> header
   file. */
#define HAVE_LINUX_NETFILTER_IPV6_IP6_TABLES_H 1

/* Define to 1 if you have the <linux/nfc.h> header file. */
#define HAVE_LINUX_NFC_H 1

/* Define to 1 if you have the <linux/qrtr.h> header file. */
#define HAVE_LINUX_QRTR_H 1

/* Define to 1 if you have the <linux/rxrpc.h> header file. */
#define HAVE_LINUX_RXRPC_H 1

/* Define to 1 if you have the <linux/vm_sockets.h> header file. */
#define HAVE_LINUX_VM_SOCKETS_H 1

/* Define to 1 if you have m32 mpers support */
/* #undef HAVE_M32_MPERS */

/* Define to enable SELinux security contexts testing for m32 personality */
/* #undef HAVE_M32_SELINUX_RUNTIME */

/* Define to 1 if m32 has the type 'struct stat'. */
/* #undef HAVE_M32_STRUCT_STAT */

/* Define to 1 if m32 has the type 'struct stat64'. */
/* #undef HAVE_M32_STRUCT_STAT64 */

/* Define to 1 if 'st_mtime_nsec' is a member of m32 'struct stat64'. */
/* #undef HAVE_M32_STRUCT_STAT64_ST_MTIME_NSEC */

/* Define to 1 if 'st_mtime_nsec' is a member of m32 'struct stat'. */
/* #undef HAVE_M32_STRUCT_STAT_ST_MTIME_NSEC */

/* Define to 1 if you have the `mempcpy' function. */
#define HAVE_MEMPCPY 1

/* Define to 1 if you have the <minix/config.h> header file. */
/* #undef HAVE_MINIX_CONFIG_H */

/* Define to 1 if you have the <mqueue.h> header file. */
#define HAVE_MQUEUE_H 1

/* Define to 1 if you have mx32 mpers support */
/* #undef HAVE_MX32_MPERS */

/* Define to enable SELinux security contexts testing for mx32 personality */
/* #undef HAVE_MX32_SELINUX_RUNTIME */

/* Define to 1 if mx32 has the type 'struct stat'. */
/* #undef HAVE_MX32_STRUCT_STAT */

/* Define to 1 if mx32 has the type 'struct stat64'. */
/* #undef HAVE_MX32_STRUCT_STAT64 */

/* Define to 1 if 'st_mtime_nsec' is a member of mx32 'struct stat64'. */
/* #undef HAVE_MX32_STRUCT_STAT64_ST_MTIME_NSEC */

/* Define to 1 if 'st_mtime_nsec' is a member of mx32 'struct stat'. */
/* #undef HAVE_MX32_STRUCT_STAT_ST_MTIME_NSEC */

/* Define to 1 if you have the <netinet/sctp.h> header file. */
/* #undef HAVE_NETINET_SCTP_H */

/* Define to 1 if you have the <netinet/tcp.h> header file. */
#define HAVE_NETINET_TCP_H 1

/* Define to 1 if you have the <netinet/udp.h> header file. */
#define HAVE_NETINET_UDP_H 1

/* Define to 1 if you have the <netipx/ipx.h> header file. */
#define HAVE_NETIPX_IPX_H 1

/* Define to 1 if you have the `open64' function. */
#define HAVE_OPEN64 1

/* Define to 1 if you have the `open_memstream' function. */
#define HAVE_OPEN_MEMSTREAM 1

/* Define to 1 if you have the <paths.h> header file. */
#define HAVE_PATHS_H 1

/* Define to 1 if you have the `preadv' function. */
#define HAVE_PREADV 1

/* Define to 1 if you have the `process_vm_readv' function. */
#define HAVE_PROCESS_VM_READV 1

/* Define to 1 if you have the `process_vm_writev' function. */
#define HAVE_PROCESS_VM_WRITEV 1

/* Define to 1 if the system provides program_invocation_name variable */
#define HAVE_PROGRAM_INVOCATION_NAME 1

/* Define to 1 if you have the `pwritev' function. */
#define HAVE_PWRITEV 1

/* Define to 1 if you have the `readahead' function. */
#define HAVE_READAHEAD 1

/* Define to 1 if the system has the type `s390_compat_regs'. */
/* #undef HAVE_S390_COMPAT_REGS */

/* Define to 1 if you have the <scsi/sg.h> header file. */
#define HAVE_SCSI_SG_H 1

/* Define to enable SELinux security contexts testing */
/* #undef HAVE_SELINUX_RUNTIME */

/* Define to 1 if you have the <selinux/selinux.h> header file. */
/* #undef HAVE_SELINUX_SELINUX_H */

/* Define to 1 if `si_addr_lsb' is a member of `siginfo_t'. */
#define HAVE_SIGINFO_T_SI_ADDR_LSB 1

/* Define to 1 if `si_lower' is a member of `siginfo_t'. */
#define HAVE_SIGINFO_T_SI_LOWER 1

/* Define to 1 if `si_overrun' is a member of `siginfo_t'. */
#define HAVE_SIGINFO_T_SI_OVERRUN 1

/* Define to 1 if `si_perf_data' is a member of `siginfo_t'. */
/* #undef HAVE_SIGINFO_T_SI_PERF_DATA */

/* Define to 1 if `si_perf_flags' is a member of `siginfo_t'. */
/* #undef HAVE_SIGINFO_T_SI_PERF_FLAGS */

/* Define to 1 if `si_perf_type' is a member of `siginfo_t'. */
/* #undef HAVE_SIGINFO_T_SI_PERF_TYPE */

/* Define to 1 if `si_pkey' is a member of `siginfo_t'. */
#define HAVE_SIGINFO_T_SI_PKEY 1

/* Define to 1 if `si_syscall' is a member of `siginfo_t'. */
#define HAVE_SIGINFO_T_SI_SYSCALL 1

/* Define to 1 if `si_timerid' is a member of `siginfo_t'. */
#define HAVE_SIGINFO_T_SI_TIMERID 1

/* Define to 1 if `si_upper' is a member of `siginfo_t'. */
#define HAVE_SIGINFO_T_SI_UPPER 1

/* Define to 1 if you have the `signalfd' function. */
#define HAVE_SIGNALFD 1

/* Define to 1 if the system has the type `sig_atomic_t'. */
#define HAVE_SIG_ATOMIC_T 1

/* Define to 1 if the system provides static_assert */
#define HAVE_STATIC_ASSERT 1

/* Define to 1 if you have the <stdint.h> header file. */
#define HAVE_STDINT_H 1

/* Define to 1 if you have the <stdio.h> header file. */
#define HAVE_STDIO_H 1

/* Define to 1 if you have the <stdlib.h> header file. */
#define HAVE_STDLIB_H 1

/* Define to 1 if you have the `stpcpy' function. */
#define HAVE_STPCPY 1

/* Define to 1 if you have the `strerror' function. */
#define HAVE_STRERROR 1

/* Define to 1 if you have the <strings.h> header file. */
#define HAVE_STRINGS_H 1

/* Define to 1 if you have the <string.h> header file. */
#define HAVE_STRING_H 1

/* Define to 1 if you have the `strndup' function. */
#define HAVE_STRNDUP 1

/* Define to 1 if the system has the type `struct bpf_insn'. */
#define HAVE_STRUCT_BPF_INSN 1

/* Define to 1 if the system has the type `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO 1

/* Define to 1 if `btf_id' is a member of `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_BTF_ID 1

/* Define to 1 if `btf_key_type_id' is a member of `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_BTF_KEY_TYPE_ID 1

/* Define to 1 if `btf_value_type_id' is a member of `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_BTF_VALUE_TYPE_ID 1

/* Define to 1 if `btf_vmlinux_value_type_id' is a member of `struct
   bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_BTF_VMLINUX_VALUE_TYPE_ID 1

/* Define to 1 if `id' is a member of `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_ID 1

/* Define to 1 if `ifindex' is a member of `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_IFINDEX 1

/* Define to 1 if `key_size' is a member of `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_KEY_SIZE 1

/* Define to 1 if `map_extra' is a member of `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_MAP_EXTRA 1

/* Define to 1 if `map_flags' is a member of `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_MAP_FLAGS 1

/* Define to 1 if `max_entries' is a member of `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_MAX_ENTRIES 1

/* Define to 1 if `name' is a member of `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_NAME 1

/* Define to 1 if `pad' is a member of `struct bpf_map_info'. */
/* #undef HAVE_STRUCT_BPF_MAP_INFO_PAD */

/* Define to 1 if `type' is a member of `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_TYPE 1

/* Define to 1 if `value_size' is a member of `struct bpf_map_info'. */
#define HAVE_STRUCT_BPF_MAP_INFO_VALUE_SIZE 1

/* Define to 1 if the system has the type `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO 1

/* Define to 1 if `btf_id' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_BTF_ID 1

/* Define to 1 if `created_by_uid' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_CREATED_BY_UID 1

/* Define to 1 if `func_info' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_FUNC_INFO 1

/* Define to 1 if `func_info_rec_size' is a member of `struct bpf_prog_info'.
   */
#define HAVE_STRUCT_BPF_PROG_INFO_FUNC_INFO_REC_SIZE 1

/* Define to 1 if `id' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_ID 1

/* Define to 1 if `ifindex' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_IFINDEX 1

/* Define to 1 if `jited_func_lens' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_JITED_FUNC_LENS 1

/* Define to 1 if `jited_ksyms' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_JITED_KSYMS 1

/* Define to 1 if `jited_line_info' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_JITED_LINE_INFO 1

/* Define to 1 if `jited_line_info_rec_size' is a member of `struct
   bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_JITED_LINE_INFO_REC_SIZE 1

/* Define to 1 if `jited_prog_insns' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_JITED_PROG_INSNS 1

/* Define to 1 if `jited_prog_len' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_JITED_PROG_LEN 1

/* Define to 1 if `line_info' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_LINE_INFO 1

/* Define to 1 if `line_info_rec_size' is a member of `struct bpf_prog_info'.
   */
#define HAVE_STRUCT_BPF_PROG_INFO_LINE_INFO_REC_SIZE 1

/* Define to 1 if `load_time' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_LOAD_TIME 1

/* Define to 1 if `map_ids' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_MAP_IDS 1

/* Define to 1 if `name' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_NAME 1

/* Define to 1 if `nr_func_info' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_NR_FUNC_INFO 1

/* Define to 1 if `nr_jited_func_lens' is a member of `struct bpf_prog_info'.
   */
#define HAVE_STRUCT_BPF_PROG_INFO_NR_JITED_FUNC_LENS 1

/* Define to 1 if `nr_jited_ksyms' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_NR_JITED_KSYMS 1

/* Define to 1 if `nr_jited_line_info' is a member of `struct bpf_prog_info'.
   */
#define HAVE_STRUCT_BPF_PROG_INFO_NR_JITED_LINE_INFO 1

/* Define to 1 if `nr_line_info' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_NR_LINE_INFO 1

/* Define to 1 if `nr_map_ids' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_NR_MAP_IDS 1

/* Define to 1 if `nr_prog_tags' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_NR_PROG_TAGS 1

/* Define to 1 if `prog_tags' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_PROG_TAGS 1

/* Define to 1 if `recursion_misses' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_RECURSION_MISSES 1

/* Define to 1 if `run_cnt' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_RUN_CNT 1

/* Define to 1 if `run_time_ns' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_RUN_TIME_NS 1

/* Define to 1 if `tag' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_TAG 1

/* Define to 1 if `type' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_TYPE 1

/* Define to 1 if `verified_insns' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_VERIFIED_INSNS 1

/* Define to 1 if `xlated_prog_insns' is a member of `struct bpf_prog_info'.
   */
#define HAVE_STRUCT_BPF_PROG_INFO_XLATED_PROG_INSNS 1

/* Define to 1 if `xlated_prog_len' is a member of `struct bpf_prog_info'. */
#define HAVE_STRUCT_BPF_PROG_INFO_XLATED_PROG_LEN 1

/* Define to 1 if the system has the type `struct ia64_fpreg'. */
/* #undef HAVE_STRUCT_IA64_FPREG */

/* Define to 1 if `aio_flags' is a member of `struct iocb'. */
#define HAVE_STRUCT_IOCB_AIO_FLAGS 1

/* Define to 1 if `aio_rw_flags' is a member of `struct iocb'. */
#define HAVE_STRUCT_IOCB_AIO_RW_FLAGS 1

/* Define to 1 if the system has the type `struct kbdiacrsuc'. */
#define HAVE_STRUCT_KBDIACRSUC 1

/* Define to 1 if the system has the type `struct kbdiacruc'. */
#define HAVE_STRUCT_KBDIACRUC 1

/* Define to 1 if the system has the type `struct kvm_cpuid2'. */
/* #undef HAVE_STRUCT_KVM_CPUID2 */

/* Define to 1 if the system has the type `struct kvm_regs'. */
/* #undef HAVE_STRUCT_KVM_REGS */

/* Define to 1 if the system has the type `struct kvm_sregs'. */
/* #undef HAVE_STRUCT_KVM_SREGS */

/* Define to 1 if the system has the type `struct
   kvm_userspace_memory_region'. */
/* #undef HAVE_STRUCT_KVM_USERSPACE_MEMORY_REGION */

/* Define to 1 if the system has the type `struct mmsghdr'. */
#define HAVE_STRUCT_MMSGHDR 1

/* Define to 1 if the system has the type `struct ptrace_peeksiginfo_args'. */
/* #undef HAVE_STRUCT_PTRACE_PEEKSIGINFO_ARGS */

/* Define to 1 if the system has the type `struct ptrace_syscall_info'. */
#define HAVE_STRUCT_PTRACE_SYSCALL_INFO 1

/* Define to 1 if the system has the type `struct pt_all_user_regs'. */
/* #undef HAVE_STRUCT_PT_ALL_USER_REGS */

/* Define to 1 if the system has the type `struct sigcontext'. */
#define HAVE_STRUCT_SIGCONTEXT 1

/* Define to 1 if the system has the type `struct sockaddr_alg_new'. */
#define HAVE_STRUCT_SOCKADDR_ALG_NEW 1

/* Define to 1 if `hci_channel' is a member of `struct sockaddr_hci'. */
#define HAVE_STRUCT_SOCKADDR_HCI_HCI_CHANNEL 1

/* Define to 1 if `l2_bdaddr_type' is a member of `struct sockaddr_l2'. */
#define HAVE_STRUCT_SOCKADDR_L2_L2_BDADDR_TYPE 1

/* Define to 1 if the system has the type `struct sockaddr_storage'. */
#define HAVE_STRUCT_SOCKADDR_STORAGE 1

/* Define to 1 if the system has the type `struct sockaddr_vm'. */
#define HAVE_STRUCT_SOCKADDR_VM 1

/* Define to 1 if `svm_flags' is a member of `struct sockaddr_vm'. */
#define HAVE_STRUCT_SOCKADDR_VM_SVM_FLAGS 1

/* Define to 1 if the system has the type `struct sockaddr_xdp'. */
#define HAVE_STRUCT_SOCKADDR_XDP 1

/* Define to 1 if the system has the type `struct stat64'. */
#define HAVE_STRUCT_STAT64 1

/* Define to 1 if `st_mtime_nsec' is a member of `struct stat64'. */
#define HAVE_STRUCT_STAT64_ST_MTIME_NSEC 1

/* Define to 1 if the system has the type `struct statfs'. */
#define HAVE_STRUCT_STATFS 1

/* Define to 1 if the system has the type `struct statfs64'. */
#define HAVE_STRUCT_STATFS64 1

/* Define to 1 if `f_flags' is a member of `struct statfs64'. */
#define HAVE_STRUCT_STATFS64_F_FLAGS 1

/* Define to 1 if `f_frsize' is a member of `struct statfs64'. */
#define HAVE_STRUCT_STATFS64_F_FRSIZE 1

/* Define to 1 if `f_fsid.val' is a member of `struct statfs64'. */
#define HAVE_STRUCT_STATFS64_F_FSID_VAL 1

/* Define to 1 if `f_fsid.__val' is a member of `struct statfs64'. */
/* #undef HAVE_STRUCT_STATFS64_F_FSID___VAL */

/* Define to 1 if `f_flags' is a member of `struct statfs'. */
#define HAVE_STRUCT_STATFS_F_FLAGS 1

/* Define to 1 if `f_frsize' is a member of `struct statfs'. */
#define HAVE_STRUCT_STATFS_F_FRSIZE 1

/* Define to 1 if `f_fsid.val' is a member of `struct statfs'. */
#define HAVE_STRUCT_STATFS_F_FSID_VAL 1

/* Define to 1 if `f_fsid.__val' is a member of `struct statfs'. */
/* #undef HAVE_STRUCT_STATFS_F_FSID___VAL */

/* Define to 1 if `st_mtime_nsec' is a member of `struct stat'. */
#define HAVE_STRUCT_STAT_ST_MTIME_NSEC 1

/* Define to 1 if the system has the type `struct tcp_diag_md5sig'. */
/* #undef HAVE_STRUCT_TCP_DIAG_MD5SIG */

/* Define to 1 if the system has the type `struct user_desc'. */
/* #undef HAVE_STRUCT_USER_DESC */

/* Define to 1 if `lm' is a member of `struct user_desc'. */
/* #undef HAVE_STRUCT_USER_DESC_LM */

/* Define to 1 if `domainname' is a member of `struct utsname'. */
#define HAVE_STRUCT_UTSNAME_DOMAINNAME 1

/* Define to 1 if the system has the type `struct __aio_sigset'. */
/* #undef HAVE_STRUCT___AIO_SIGSET */

/* Define to 1 if the system has the type `struct __kernel_sock_timeval'. */
#define HAVE_STRUCT___KERNEL_SOCK_TIMEVAL 1

/* Define to 1 if the system has the type `struct __kernel_timespec'. */
#define HAVE_STRUCT___KERNEL_TIMESPEC 1

/* Define to 1 if the system has the type `struct __old_kernel_stat'. */
#define HAVE_STRUCT___OLD_KERNEL_STAT 1

/* Define to 1 if the system has the type `struct __ptrace_syscall_info'. */
#define HAVE_STRUCT___PTRACE_SYSCALL_INFO 1

/* Define to 1 if you have the `sync_file_range' function. */
#define HAVE_SYNC_FILE_RANGE 1

/* Define to 1 if you have the <sys/eventfd.h> header file. */
#define HAVE_SYS_EVENTFD_H 1

/* Define to 1 if you have the <sys/fanotify.h> header file. */
#define HAVE_SYS_FANOTIFY_H 1

/* Define to 1 if you have the <sys/ipc.h> header file. */
#define HAVE_SYS_IPC_H 1

/* Define to 1 if you have the <sys/quota.h> header file. */
#define HAVE_SYS_QUOTA_H 1

/* Define to 1 if you have the <sys/signalfd.h> header file. */
#define HAVE_SYS_SIGNALFD_H 1

/* Define to 1 if you have the <sys/stat.h> header file. */
#define HAVE_SYS_STAT_H 1

/* Define to 1 if you have the <sys/types.h> header file. */
#define HAVE_SYS_TYPES_H 1

/* Define to 1 if you have the <sys/xattr.h> header file. */
#define HAVE_SYS_XATTR_H 1

/* Define to 1 if typeof works with your compiler. */
#define HAVE_TYPEOF 1

/* Define to 1 if `attach_bpf_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_ATTACH_BPF_FD 1

/* Define to 1 if `attach_btf_id' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_ATTACH_BTF_ID 1

/* Define to 1 if `attach_flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_ATTACH_FLAGS 1

/* Define to 1 if `attach_prog_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_ATTACH_PROG_FD 1

/* Define to 1 if `attach_type' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_ATTACH_TYPE 1

/* Define to 1 if `batch.count' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BATCH_COUNT 1

/* Define to 1 if `batch.elem_flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BATCH_ELEM_FLAGS 1

/* Define to 1 if `batch.flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BATCH_FLAGS 1

/* Define to 1 if `batch.in_batch' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BATCH_IN_BATCH 1

/* Define to 1 if `batch.keys' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BATCH_KEYS 1

/* Define to 1 if `batch.map_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BATCH_MAP_FD 1

/* Define to 1 if `batch.out_batch' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BATCH_OUT_BATCH 1

/* Define to 1 if `batch.values' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BATCH_VALUES 1

/* Define to 1 if `bpf_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BPF_FD 1

/* Define to 1 if `btf' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BTF 1

/* Define to 1 if `btf_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BTF_FD 1

/* Define to 1 if `btf_id' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BTF_ID 1

/* Define to 1 if `btf_key_type_id' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BTF_KEY_TYPE_ID 1

/* Define to 1 if `btf_log_buf' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BTF_LOG_BUF 1

/* Define to 1 if `btf_log_level' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BTF_LOG_LEVEL 1

/* Define to 1 if `btf_log_size' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BTF_LOG_SIZE 1

/* Define to 1 if `btf_size' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BTF_SIZE 1

/* Define to 1 if `btf_value_type_id' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_BTF_VALUE_TYPE_ID 1

/* Define to 1 if `btf_vmlinux_value_type_id' is a member of `union bpf_attr'.
   */
#define HAVE_UNION_BPF_ATTR_BTF_VMLINUX_VALUE_TYPE_ID 1

/* Define to 1 if `dummy' is a member of `union bpf_attr'. */
/* #undef HAVE_UNION_BPF_ATTR_DUMMY */

/* Define to 1 if `expected_attach_type' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_EXPECTED_ATTACH_TYPE 1

/* Define to 1 if `fd_array' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_FD_ARRAY 1

/* Define to 1 if `file_flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_FILE_FLAGS 1

/* Define to 1 if `flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_FLAGS 1

/* Define to 1 if `func_info' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_FUNC_INFO 1

/* Define to 1 if `func_info_cnt' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_FUNC_INFO_CNT 1

/* Define to 1 if `func_info_rec_size' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_FUNC_INFO_REC_SIZE 1

/* Define to 1 if `info.bpf_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_INFO_BPF_FD 1

/* Define to 1 if `info.info' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_INFO_INFO 1

/* Define to 1 if `info.info_len' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_INFO_INFO_LEN 1

/* Define to 1 if `inner_map_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_INNER_MAP_FD 1

/* Define to 1 if `insns' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_INSNS 1

/* Define to 1 if `insn_cnt' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_INSN_CNT 1

/* Define to 1 if `kern_version' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_KERN_VERSION 1

/* Define to 1 if `key' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_KEY 1

/* Define to 1 if `key_size' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_KEY_SIZE 1

/* Define to 1 if `license' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LICENSE 1

/* Define to 1 if `line_info' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LINE_INFO 1

/* Define to 1 if `line_info_cnt' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LINE_INFO_CNT 1

/* Define to 1 if `line_info_rec_size' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LINE_INFO_REC_SIZE 1

/* Define to 1 if `link_create.addrs' is a member of `union bpf_attr'. */
/* #undef HAVE_UNION_BPF_ATTR_LINK_CREATE_ADDRS */

/* Define to 1 if `link_create.attach_type' is a member of `union bpf_attr'.
   */
#define HAVE_UNION_BPF_ATTR_LINK_CREATE_ATTACH_TYPE 1

/* Define to 1 if `link_create.bpf_cookie' is a member of `union bpf_attr'. */
/* #undef HAVE_UNION_BPF_ATTR_LINK_CREATE_BPF_COOKIE */

/* Define to 1 if `link_create.cnt' is a member of `union bpf_attr'. */
/* #undef HAVE_UNION_BPF_ATTR_LINK_CREATE_CNT */

/* Define to 1 if `link_create.cookies' is a member of `union bpf_attr'. */
/* #undef HAVE_UNION_BPF_ATTR_LINK_CREATE_COOKIES */

/* Define to 1 if `link_create.flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LINK_CREATE_FLAGS 1

/* Define to 1 if `link_create.iter_info' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LINK_CREATE_ITER_INFO 1

/* Define to 1 if `link_create.iter_info_len' is a member of `union bpf_attr'.
   */
#define HAVE_UNION_BPF_ATTR_LINK_CREATE_ITER_INFO_LEN 1

/* Define to 1 if `link_create.kprobe_multi' is a member of `union bpf_attr'.
   */
#define HAVE_UNION_BPF_ATTR_LINK_CREATE_KPROBE_MULTI 1

/* Define to 1 if `link_create.perf_event' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LINK_CREATE_PERF_EVENT 1

/* Define to 1 if `link_create.prog_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LINK_CREATE_PROG_FD 1

/* Define to 1 if `link_create.syms' is a member of `union bpf_attr'. */
/* #undef HAVE_UNION_BPF_ATTR_LINK_CREATE_SYMS */

/* Define to 1 if `link_create.target_btf_id' is a member of `union bpf_attr'.
   */
#define HAVE_UNION_BPF_ATTR_LINK_CREATE_TARGET_BTF_ID 1

/* Define to 1 if `link_create.target_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LINK_CREATE_TARGET_FD 1

/* Define to 1 if `link_id' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LINK_ID 1

/* Define to 1 if `link_update.flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LINK_UPDATE_FLAGS 1

/* Define to 1 if `link_update.link_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LINK_UPDATE_LINK_FD 1

/* Define to 1 if `link_update.new_prog_fd' is a member of `union bpf_attr'.
   */
#define HAVE_UNION_BPF_ATTR_LINK_UPDATE_NEW_PROG_FD 1

/* Define to 1 if `link_update.old_prog_fd' is a member of `union bpf_attr'.
   */
#define HAVE_UNION_BPF_ATTR_LINK_UPDATE_OLD_PROG_FD 1

/* Define to 1 if `log_buf' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LOG_BUF 1

/* Define to 1 if `log_level' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LOG_LEVEL 1

/* Define to 1 if `log_size' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_LOG_SIZE 1

/* Define to 1 if `map_extra' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_MAP_EXTRA 1

/* Define to 1 if `map_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_MAP_FD 1

/* Define to 1 if `map_flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_MAP_FLAGS 1

/* Define to 1 if `map_id' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_MAP_ID 1

/* Define to 1 if `map_ifindex' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_MAP_IFINDEX 1

/* Define to 1 if `map_name' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_MAP_NAME 1

/* Define to 1 if `map_type' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_MAP_TYPE 1

/* Define to 1 if `max_entries' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_MAX_ENTRIES 1

/* Define to 1 if `next_id' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_NEXT_ID 1

/* Define to 1 if `next_key' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_NEXT_KEY 1

/* Define to 1 if `numa_node' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_NUMA_NODE 1

/* Define to 1 if `open_flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_OPEN_FLAGS 1

/* Define to 1 if `pad' is a member of `union bpf_attr'. */
/* #undef HAVE_UNION_BPF_ATTR_PAD */

/* Define to 1 if `pathname' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_PATHNAME 1

/* Define to 1 if `prog_btf_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_PROG_BTF_FD 1

/* Define to 1 if `prog_flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_PROG_FLAGS 1

/* Define to 1 if `prog_id' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_PROG_ID 1

/* Define to 1 if `prog_ifindex' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_PROG_IFINDEX 1

/* Define to 1 if `prog_name' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_PROG_NAME 1

/* Define to 1 if `prog_type' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_PROG_TYPE 1

/* Define to 1 if `query.attach_flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_QUERY_ATTACH_FLAGS 1

/* Define to 1 if `query.attach_type' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_QUERY_ATTACH_TYPE 1

/* Define to 1 if `query.prog_cnt' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_QUERY_PROG_CNT 1

/* Define to 1 if `query.prog_ids' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_QUERY_PROG_IDS 1

/* Define to 1 if `query.query_flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_QUERY_QUERY_FLAGS 1

/* Define to 1 if `query.target_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_QUERY_TARGET_FD 1

/* Define to 1 if `raw_tracepoint.name' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_RAW_TRACEPOINT_NAME 1

/* Define to 1 if `raw_tracepoint.prog_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_RAW_TRACEPOINT_PROG_FD 1

/* Define to 1 if `replace_bpf_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_REPLACE_BPF_FD 1

/* Define to 1 if `start_id' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_START_ID 1

/* Define to 1 if `target_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TARGET_FD 1

/* Define to 1 if `task_fd_query.buf' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_BUF 1

/* Define to 1 if `task_fd_query.buf_len' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_BUF_LEN 1

/* Define to 1 if `task_fd_query.fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_FD 1

/* Define to 1 if `task_fd_query.fd_type' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_FD_TYPE 1

/* Define to 1 if `task_fd_query.flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_FLAGS 1

/* Define to 1 if `task_fd_query.pid' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_PID 1

/* Define to 1 if `task_fd_query.probe_addr' is a member of `union bpf_attr'.
   */
#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_PROBE_ADDR 1

/* Define to 1 if `task_fd_query.probe_offset' is a member of `union
   bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_PROBE_OFFSET 1

/* Define to 1 if `task_fd_query.prog_id' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_PROG_ID 1

/* Define to 1 if `test.batch_size' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_BATCH_SIZE 1

/* Define to 1 if `test.cpu' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_CPU 1

/* Define to 1 if `test.ctx_in' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_CTX_IN 1

/* Define to 1 if `test.ctx_out' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_CTX_OUT 1

/* Define to 1 if `test.ctx_size_in' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_CTX_SIZE_IN 1

/* Define to 1 if `test.ctx_size_out' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_CTX_SIZE_OUT 1

/* Define to 1 if `test.data_in' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_DATA_IN 1

/* Define to 1 if `test.data_out' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_DATA_OUT 1

/* Define to 1 if `test.data_size_in' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_DATA_SIZE_IN 1

/* Define to 1 if `test.data_size_out' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_DATA_SIZE_OUT 1

/* Define to 1 if `test.duration' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_DURATION 1

/* Define to 1 if `test.flags' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_FLAGS 1

/* Define to 1 if `test.prog_fd' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_PROG_FD 1

/* Define to 1 if `test.repeat' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_REPEAT 1

/* Define to 1 if `test.retval' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_TEST_RETVAL 1

/* Define to 1 if `value' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_VALUE 1

/* Define to 1 if `value_size' is a member of `union bpf_attr'. */
#define HAVE_UNION_BPF_ATTR_VALUE_SIZE 1

/* Define to 1 if you have the <unistd.h> header file. */
#define HAVE_UNISTD_H 1

/* Define to 1 if you have the <ustat.h> header file. */
/* #undef HAVE_USTAT_H */

/* Define to 1 if you have the <wchar.h> header file. */
#define HAVE_WCHAR_H 1

/* Define to 1 if the system provides _Static_assert */
/* #undef HAVE__STATIC_ASSERT */

/* Define to 1 if the system provides __builtin_popcount function */
#define HAVE___BUILTIN_POPCOUNT 1

/* Define to 1 if the system has the type `__kernel_long_t'. */
#define HAVE___KERNEL_LONG_T 1

/* Define to 1 if the system has the type `__kernel_ulong_t'. */
#define HAVE___KERNEL_ULONG_T 1

/* Define for the HPPA architecture. */
/* #undef HPPA */

/* Define for the i386 architecture. */
/* #undef I386 */

/* Define for the IA64 architecture. */
/* #undef IA64 */

/* Define for _ABIN32. */
/* #undef LINUX_MIPSN32 */

/* Define for _ABI64. */
/* #undef LINUX_MIPSN64 */

/* Define for _ABIO32. */
/* #undef LINUX_MIPSO32 */

/* Define for the 64-bit LoongArch architecture. */
/* #undef LOONGARCH64 */

/* The size of `kernel_long_t', as computed by sizeof. */
/* #undef M32_SIZEOF_KERNEL_LONG_T */

/* The size of `long', as computed by sizeof. */
/* #undef M32_SIZEOF_LONG */

/* The size of `struct msqid64_ds', as computed by sizeof. */
/* #undef M32_SIZEOF_STRUCT_MSQID64_DS */

/* Define for the m68k architecture. */
/* #undef M68K */

/* Define for the Meta architecture. */
/* #undef METAG */

/* Define for the MicroBlaze architecture. */
/* #undef MICROBLAZE */

/* Define for the MIPS architecture. */
/* #undef MIPS */

/* The size of `kernel_long_t', as computed by sizeof. */
/* #undef MX32_SIZEOF_KERNEL_LONG_T */

/* The size of `long', as computed by sizeof. */
/* #undef MX32_SIZEOF_LONG */

/* The size of `struct msqid64_ds', as computed by sizeof. */
/* #undef MX32_SIZEOF_STRUCT_MSQID64_DS */

/* Define for the Nios-II architecture. */
/* #undef NIOS2 */

/* Define for the OpenRISC 1000 architecture. */
/* #undef OR1K */

/* Name of package */
#define PACKAGE "strace"

/* Define to the address where bug reports for this package should be sent. */
#define PACKAGE_BUGREPORT "strace-devel@lists.strace.io"

/* Define to the full name of this package. */
#define PACKAGE_NAME "strace"

/* Define to the full name and version of this package. */
#define PACKAGE_STRING "strace 5.19"

/* Define to the one symbol short name of this package. */
#define PACKAGE_TARNAME "strace"

/* Define to the home page for this package. */
#define PACKAGE_URL "https://strace.io"

/* Define to the version of this package. */
#define PACKAGE_VERSION "5.19"

/* Define for the PowerPC architecture. */
/* #undef POWERPC */

/* Define for the big endian PowerPC64 architecture. */
/* #undef POWERPC64 */

/* Define for the little endian PowerPC64 architecture. */
/* #undef POWERPC64LE */

/* Define for the RISC-V 64-bit architecture */
/* #undef RISCV64 */

/* Define for the S390 architecture. */
/* #undef S390 */

/* Define for the S390x architecture. */
/* #undef S390X */

/* Define for the SH architecture. */
/* #undef SH */

/* Define for the SH64 architecture. */
/* #undef SH64 */

/* The size of `kernel_long_t', as computed by sizeof. */
#define SIZEOF_KERNEL_LONG_T 4

/* The size of `long', as computed by sizeof. */
#define SIZEOF_LONG 4

/* The size of `long long', as computed by sizeof. */
#define SIZEOF_LONG_LONG 8

/* The size of `off_t', as computed by sizeof. */
#define SIZEOF_OFF_T 4

/* The size of `struct i64_i32', as computed by sizeof. */
#define SIZEOF_STRUCT_I64_I32 16

/* The size of `struct msqid64_ds', as computed by sizeof. */
#define SIZEOF_STRUCT_MSQID64_DS 88

/* Date */
#define SLM_MANPAGE_DATE "2022-01-01"

/* Define for the SPARC architecture. */
/* #undef SPARC */

/* Define for the SPARC64 architecture. */
/* #undef SPARC64 */

/* Define to 1 if all of the C90 standard headers exist (not just the ones
   required in a freestanding environment). This macro is provided for
   backward compatibility; new code need not use it. */
#define STDC_HEADERS 1

/* Date */
#define STRACE_MANPAGE_DATE "2022-07-19"

/* Define for the Tile architecture */
/* #undef TILE */

/* Do symbols demangling in stack trace */
/* #undef USE_DEMANGLE */

/* Whether to use libdw for stack tracing */
/* #undef USE_LIBDW */

/* Whether to use libunwind for stack tracing */
/* #undef USE_LIBUNWIND */

/* Enable extensions on AIX 3, Interix.  */
#ifndef _ALL_SOURCE
# define _ALL_SOURCE 1
#endif
/* Enable general extensions on macOS.  */
#ifndef _DARWIN_C_SOURCE
# define _DARWIN_C_SOURCE 1
#endif
/* Enable general extensions on Solaris.  */
#ifndef __EXTENSIONS__
# define __EXTENSIONS__ 1
#endif
/* Enable GNU extensions on systems that have them.  */
#ifndef _GNU_SOURCE
# define _GNU_SOURCE 1
#endif
/* Enable X/Open compliant socket functions that do not require linking
   with -lxnet on HP-UX 11.11.  */
#ifndef _HPUX_ALT_XOPEN_SOCKET_API
# define _HPUX_ALT_XOPEN_SOCKET_API 1
#endif
/* Identify the host operating system as Minix.
   This macro does not affect the system headers' behavior.
   A future release of Autoconf may stop defining this macro.  */
#ifndef _MINIX
/* # undef _MINIX */
#endif
/* Enable general extensions on NetBSD.
   Enable NetBSD compatibility extensions on Minix.  */
#ifndef _NETBSD_SOURCE
# define _NETBSD_SOURCE 1
#endif
/* Enable OpenBSD compatibility extensions on NetBSD.
   Oddly enough, this does nothing on OpenBSD.  */
#ifndef _OPENBSD_SOURCE
# define _OPENBSD_SOURCE 1
#endif
/* Define to 1 if needed for POSIX-compatible behavior.  */
#ifndef _POSIX_SOURCE
/* # undef _POSIX_SOURCE */
#endif
/* Define to 2 if needed for POSIX-compatible behavior.  */
#ifndef _POSIX_1_SOURCE
/* # undef _POSIX_1_SOURCE */
#endif
/* Enable POSIX-compatible threading on Solaris.  */
#ifndef _POSIX_PTHREAD_SEMANTICS
# define _POSIX_PTHREAD_SEMANTICS 1
#endif
/* Enable extensions specified by ISO/IEC TS 18661-5:2014.  */
#ifndef __STDC_WANT_IEC_60559_ATTRIBS_EXT__
# define __STDC_WANT_IEC_60559_ATTRIBS_EXT__ 1
#endif
/* Enable extensions specified by ISO/IEC TS 18661-1:2014.  */
#ifndef __STDC_WANT_IEC_60559_BFP_EXT__
# define __STDC_WANT_IEC_60559_BFP_EXT__ 1
#endif
/* Enable extensions specified by ISO/IEC TS 18661-2:2015.  */
#ifndef __STDC_WANT_IEC_60559_DFP_EXT__
# define __STDC_WANT_IEC_60559_DFP_EXT__ 1
#endif
/* Enable extensions specified by ISO/IEC TS 18661-4:2015.  */
#ifndef __STDC_WANT_IEC_60559_FUNCS_EXT__
# define __STDC_WANT_IEC_60559_FUNCS_EXT__ 1
#endif
/* Enable extensions specified by ISO/IEC TS 18661-3:2015.  */
#ifndef __STDC_WANT_IEC_60559_TYPES_EXT__
# define __STDC_WANT_IEC_60559_TYPES_EXT__ 1
#endif
/* Enable extensions specified by ISO/IEC TR 24731-2:2010.  */
#ifndef __STDC_WANT_LIB_EXT2__
# define __STDC_WANT_LIB_EXT2__ 1
#endif
/* Enable extensions specified by ISO/IEC 24747:2009.  */
#ifndef __STDC_WANT_MATH_SPEC_FUNCS__
# define __STDC_WANT_MATH_SPEC_FUNCS__ 1
#endif
/* Enable extensions on HP NonStop.  */
#ifndef _TANDEM_SOURCE
# define _TANDEM_SOURCE 1
#endif
/* Enable X/Open extensions.  Define to 500 only if necessary
   to make mbstate_t available.  */
#ifndef _XOPEN_SOURCE
/* # undef _XOPEN_SOURCE */
#endif


/* The unwinder to use for stack tracing support */
/* #undef USE_UNWINDER */

/* Version number of package */
#define VERSION "5.19"

/* Define WORDS_BIGENDIAN to 1 if your processor stores words with the most
   significant byte first (like Motorola and SPARC, unlike Intel). */
#if defined AC_APPLE_UNIVERSAL_BUILD
# if defined __BIG_ENDIAN__
#  define WORDS_BIGENDIAN 1
# endif
#else
# ifndef WORDS_BIGENDIAN
/* #  undef WORDS_BIGENDIAN */
# endif
#endif

/* Define for the 32bit AMD x86-64 architecture. */
/* #undef X32 */

/* Define for the 64bit AMD x86-64 architecture. */
/* #undef X86_64 */

/* Define for the Xtensa architecture */
/* #undef XTENSA */

/* Define to `int' if <sys/types.h> doesn't define. */
/* #undef gid_t */

/* Define to __typeof__ if your compiler spells it that way. */
/* #undef typeof */

/* Define to `int' if <sys/types.h> doesn't define. */
/* #undef uid_t */
