/* Generated by ./src/xlat/gen.sh from ./src/xlat/lirc_features.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat lirc_features in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data lirc_features_xdata[] = {
 XLAT(LIRC_CAN_SEND_PULSE),
 #define XLAT_VAL_0 ((unsigned) (LIRC_CAN_SEND_PULSE))
 #define XLAT_STR_0 STRINGIFY(LIRC_CAN_SEND_PULSE)
 XLAT(LIRC_CAN_SEND_LIRCCODE),
 #define XLAT_VAL_1 ((unsigned) (LIRC_CAN_SEND_LIRCCODE))
 #define XLAT_STR_1 STRINGIFY(LIRC_CAN_SEND_LIRCCODE)
 XLAT(LIRC_CAN_SET_SEND_CARRIER),
 #define XLAT_VAL_2 ((unsigned) (LIRC_CAN_SET_SEND_CARRIER))
 #define XLAT_STR_2 STRINGIFY(LIRC_CAN_SET_SEND_CARRIER)
 XLAT(LIRC_CAN_SET_SEND_DUTY_CYCLE),
 #define XLAT_VAL_3 ((unsigned) (LIRC_CAN_SET_SEND_DUTY_CYCLE))
 #define XLAT_STR_3 STRINGIFY(LIRC_CAN_SET_SEND_DUTY_CYCLE)
 XLAT(LIRC_CAN_SET_TRANSMITTER_MASK),
 #define XLAT_VAL_4 ((unsigned) (LIRC_CAN_SET_TRANSMITTER_MASK))
 #define XLAT_STR_4 STRINGIFY(LIRC_CAN_SET_TRANSMITTER_MASK)
 XLAT(LIRC_CAN_REC_MODE2),
 #define XLAT_VAL_5 ((unsigned) (LIRC_CAN_REC_MODE2))
 #define XLAT_STR_5 STRINGIFY(LIRC_CAN_REC_MODE2)
 XLAT(LIRC_CAN_REC_SCANCODE),
 #define XLAT_VAL_6 ((unsigned) (LIRC_CAN_REC_SCANCODE))
 #define XLAT_STR_6 STRINGIFY(LIRC_CAN_REC_SCANCODE)
 XLAT(LIRC_CAN_REC_LIRCCODE),
 #define XLAT_VAL_7 ((unsigned) (LIRC_CAN_REC_LIRCCODE))
 #define XLAT_STR_7 STRINGIFY(LIRC_CAN_REC_LIRCCODE)
 XLAT(LIRC_CAN_SET_REC_CARRIER),
 #define XLAT_VAL_8 ((unsigned) (LIRC_CAN_SET_REC_CARRIER))
 #define XLAT_STR_8 STRINGIFY(LIRC_CAN_SET_REC_CARRIER)
 XLAT(LIRC_CAN_MEASURE_CARRIER),
 #define XLAT_VAL_9 ((unsigned) (LIRC_CAN_MEASURE_CARRIER))
 #define XLAT_STR_9 STRINGIFY(LIRC_CAN_MEASURE_CARRIER)
 XLAT(LIRC_CAN_USE_WIDEBAND_RECEIVER),
 #define XLAT_VAL_10 ((unsigned) (LIRC_CAN_USE_WIDEBAND_RECEIVER))
 #define XLAT_STR_10 STRINGIFY(LIRC_CAN_USE_WIDEBAND_RECEIVER)
 XLAT(LIRC_CAN_SET_REC_TIMEOUT),
 #define XLAT_VAL_11 ((unsigned) (LIRC_CAN_SET_REC_TIMEOUT))
 #define XLAT_STR_11 STRINGIFY(LIRC_CAN_SET_REC_TIMEOUT)
 XLAT(LIRC_CAN_GET_REC_RESOLUTION),
 #define XLAT_VAL_12 ((unsigned) (LIRC_CAN_GET_REC_RESOLUTION))
 #define XLAT_STR_12 STRINGIFY(LIRC_CAN_GET_REC_RESOLUTION)
 XLAT(LIRC_CAN_SET_REC_CARRIER_RANGE),
 #define XLAT_VAL_13 ((unsigned) (LIRC_CAN_SET_REC_CARRIER_RANGE))
 #define XLAT_STR_13 STRINGIFY(LIRC_CAN_SET_REC_CARRIER_RANGE)
};
static
const struct xlat lirc_features[1] = { {
 .data = lirc_features_xdata,
 .size = ARRAY_SIZE(lirc_features_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
