/* Generated by ./src/xlat/gen.sh from ./src/xlat/nfc_sockaddr_protocols.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NFC_PROTO_JEWEL) == (1), "NFC_PROTO_JEWEL != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NFC_PROTO_MIFARE) == (2), "NFC_PROTO_MIFARE != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NFC_PROTO_FELICA) == (3), "NFC_PROTO_FELICA != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NFC_PROTO_ISO14443) == (4), "NFC_PROTO_ISO14443 != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NFC_PROTO_NFC_DEP) == (5), "NFC_PROTO_NFC_DEP != 5");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NFC_PROTO_ISO14443_B) == (6), "NFC_PROTO_ISO14443_B != 6");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NFC_PROTO_ISO15693) == (7), "NFC_PROTO_ISO15693 != 7");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat nfc_sockaddr_protocols in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data nfc_sockaddr_protocols_xdata[] = {
 [NFC_PROTO_JEWEL] = XLAT(NFC_PROTO_JEWEL),
 #define XLAT_VAL_0 ((unsigned) (NFC_PROTO_JEWEL))
 #define XLAT_STR_0 STRINGIFY(NFC_PROTO_JEWEL)
 [NFC_PROTO_MIFARE] = XLAT(NFC_PROTO_MIFARE),
 #define XLAT_VAL_1 ((unsigned) (NFC_PROTO_MIFARE))
 #define XLAT_STR_1 STRINGIFY(NFC_PROTO_MIFARE)
 [NFC_PROTO_FELICA] = XLAT(NFC_PROTO_FELICA),
 #define XLAT_VAL_2 ((unsigned) (NFC_PROTO_FELICA))
 #define XLAT_STR_2 STRINGIFY(NFC_PROTO_FELICA)
 [NFC_PROTO_ISO14443] = XLAT(NFC_PROTO_ISO14443),
 #define XLAT_VAL_3 ((unsigned) (NFC_PROTO_ISO14443))
 #define XLAT_STR_3 STRINGIFY(NFC_PROTO_ISO14443)
 [NFC_PROTO_NFC_DEP] = XLAT(NFC_PROTO_NFC_DEP),
 #define XLAT_VAL_4 ((unsigned) (NFC_PROTO_NFC_DEP))
 #define XLAT_STR_4 STRINGIFY(NFC_PROTO_NFC_DEP)
 [NFC_PROTO_ISO14443_B] = XLAT(NFC_PROTO_ISO14443_B),
 #define XLAT_VAL_5 ((unsigned) (NFC_PROTO_ISO14443_B))
 #define XLAT_STR_5 STRINGIFY(NFC_PROTO_ISO14443_B)
 [NFC_PROTO_ISO15693] = XLAT(NFC_PROTO_ISO15693),
 #define XLAT_VAL_6 ((unsigned) (NFC_PROTO_ISO15693))
 #define XLAT_STR_6 STRINGIFY(NFC_PROTO_ISO15693)
};
static
const struct xlat nfc_sockaddr_protocols[1] = { {
 .data = nfc_sockaddr_protocols_xdata,
 .size = ARRAY_SIZE(nfc_sockaddr_protocols_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
