/* Generated by ./src/xlat/gen.sh from ./src/xlat/membarrier_cmds.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(MEMBARRIER_CMD_QUERY) || (defined(HAVE_DECL_MEMBARRIER_CMD_QUERY) && HAVE_DECL_MEMBARRIER_CMD_QUERY)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MEMBARRIER_CMD_QUERY) == (0), "MEMBARRIER_CMD_QUERY != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MEMBARRIER_CMD_QUERY 0
#endif
#if defined(MEMBARRIER_CMD_GLOBAL) || (defined(HAVE_DECL_MEMBARRIER_CMD_GLOBAL) && HAVE_DECL_MEMBARRIER_CMD_GLOBAL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MEMBARRIER_CMD_GLOBAL) == ((1 << 0)), "MEMBARRIER_CMD_GLOBAL != (1 << 0)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MEMBARRIER_CMD_GLOBAL (1 << 0)
#endif
#if defined(MEMBARRIER_CMD_GLOBAL_EXPEDITED) || (defined(HAVE_DECL_MEMBARRIER_CMD_GLOBAL_EXPEDITED) && HAVE_DECL_MEMBARRIER_CMD_GLOBAL_EXPEDITED)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MEMBARRIER_CMD_GLOBAL_EXPEDITED) == ((1 << 1)), "MEMBARRIER_CMD_GLOBAL_EXPEDITED != (1 << 1)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MEMBARRIER_CMD_GLOBAL_EXPEDITED (1 << 1)
#endif
#if defined(MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED) || (defined(HAVE_DECL_MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED) && HAVE_DECL_MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED) == ((1 << 2)), "MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED != (1 << 2)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED (1 << 2)
#endif
#if defined(MEMBARRIER_CMD_PRIVATE_EXPEDITED) || (defined(HAVE_DECL_MEMBARRIER_CMD_PRIVATE_EXPEDITED) && HAVE_DECL_MEMBARRIER_CMD_PRIVATE_EXPEDITED)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MEMBARRIER_CMD_PRIVATE_EXPEDITED) == ((1 << 3)), "MEMBARRIER_CMD_PRIVATE_EXPEDITED != (1 << 3)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MEMBARRIER_CMD_PRIVATE_EXPEDITED (1 << 3)
#endif
#if defined(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED) || (defined(HAVE_DECL_MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED) && HAVE_DECL_MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED) == ((1 << 4)), "MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED != (1 << 4)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED (1 << 4)
#endif
#if defined(MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE) || (defined(HAVE_DECL_MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE) && HAVE_DECL_MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE) == ((1 << 5)), "MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE != (1 << 5)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE (1 << 5)
#endif
#if defined(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE) || (defined(HAVE_DECL_MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE) && HAVE_DECL_MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE) == ((1 << 6)), "MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE != (1 << 6)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE (1 << 6)
#endif
#if defined(MEMBARRIER_CMD_PRIVATE_EXPEDITED_RSEQ) || (defined(HAVE_DECL_MEMBARRIER_CMD_PRIVATE_EXPEDITED_RSEQ) && HAVE_DECL_MEMBARRIER_CMD_PRIVATE_EXPEDITED_RSEQ)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MEMBARRIER_CMD_PRIVATE_EXPEDITED_RSEQ) == ((1 << 7)), "MEMBARRIER_CMD_PRIVATE_EXPEDITED_RSEQ != (1 << 7)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MEMBARRIER_CMD_PRIVATE_EXPEDITED_RSEQ (1 << 7)
#endif
#if defined(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_RSEQ) || (defined(HAVE_DECL_MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_RSEQ) && HAVE_DECL_MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_RSEQ)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_RSEQ) == ((1 << 8)), "MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_RSEQ != (1 << 8)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_RSEQ (1 << 8)
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat membarrier_cmds in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data membarrier_cmds_xdata[] = {
 XLAT(MEMBARRIER_CMD_QUERY),
 #define XLAT_VAL_0 ((unsigned) (MEMBARRIER_CMD_QUERY))
 #define XLAT_STR_0 STRINGIFY(MEMBARRIER_CMD_QUERY)
 XLAT(MEMBARRIER_CMD_GLOBAL),
 #define XLAT_VAL_1 ((unsigned) (MEMBARRIER_CMD_GLOBAL))
 #define XLAT_STR_1 STRINGIFY(MEMBARRIER_CMD_GLOBAL)
 XLAT(MEMBARRIER_CMD_GLOBAL_EXPEDITED),
 #define XLAT_VAL_2 ((unsigned) (MEMBARRIER_CMD_GLOBAL_EXPEDITED))
 #define XLAT_STR_2 STRINGIFY(MEMBARRIER_CMD_GLOBAL_EXPEDITED)
 XLAT(MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED),
 #define XLAT_VAL_3 ((unsigned) (MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED))
 #define XLAT_STR_3 STRINGIFY(MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED)
 XLAT(MEMBARRIER_CMD_PRIVATE_EXPEDITED),
 #define XLAT_VAL_4 ((unsigned) (MEMBARRIER_CMD_PRIVATE_EXPEDITED))
 #define XLAT_STR_4 STRINGIFY(MEMBARRIER_CMD_PRIVATE_EXPEDITED)
 XLAT(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED),
 #define XLAT_VAL_5 ((unsigned) (MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED))
 #define XLAT_STR_5 STRINGIFY(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED)
 XLAT(MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE),
 #define XLAT_VAL_6 ((unsigned) (MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE))
 #define XLAT_STR_6 STRINGIFY(MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE)
 XLAT(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE),
 #define XLAT_VAL_7 ((unsigned) (MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE))
 #define XLAT_STR_7 STRINGIFY(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE)
 XLAT(MEMBARRIER_CMD_PRIVATE_EXPEDITED_RSEQ),
 #define XLAT_VAL_8 ((unsigned) (MEMBARRIER_CMD_PRIVATE_EXPEDITED_RSEQ))
 #define XLAT_STR_8 STRINGIFY(MEMBARRIER_CMD_PRIVATE_EXPEDITED_RSEQ)
 XLAT(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_RSEQ),
 #define XLAT_VAL_9 ((unsigned) (MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_RSEQ))
 #define XLAT_STR_9 STRINGIFY(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_RSEQ)
};
static
const struct xlat membarrier_cmds[1] = { {
 .data = membarrier_cmds_xdata,
 .size = ARRAY_SIZE(membarrier_cmds_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
